@@ -1,15 +1,4 @@
 #include "aboutdialog.h"
-//#include <QDebug>
-//#include "coreicons.h"
-
-//#include <app/app_version.h>
-//#include <coreplugin/coreicons.h>
-//#include <coreplugin/icore.h>
-//#include <utils/algorithm.h>
-//#include <utils/hostosinfo.h>
-//#include <utils/qtcassert.h>
-//#include <utils/utilsicons.h>
-
 #include <QDialogButtonBox>
 #include <QGridLayout>
 #include <QKeyEvent>
@@ -17,10 +6,10 @@
 #include <QPushButton>
 #include <QDebug>
 
-AboutDialog::AboutDialog(const QString tversion, QWidget *parent)
+AboutDialog::AboutDialog(const QString &tversion, QWidget *parent)
     : QDialog(parent)
 {
-    //qDebug() << "AboutDialog::AboutDialog" << endl;
+      //qDebug() << "AboutDialog::AboutDialog" << endl;
 
     QPixmap pixmap(":/img/klog_256x256.png");
 
@@ -33,17 +22,17 @@ AboutDialog::AboutDialog(const QString tversion, QWidget *parent)
     const QString br = QLatin1String("<br/>");
 
     const QString description = "<center><h2>KLog " + tversion + "</h2><h4> " +tr("By") +
-            " <a href=\"https://www.qrz.com/db/ea4tv\">EA4TV</a> - 2002-2019</h4></center><br>" +
+            " <a href=\"https://www.qrz.com/db/ea4k\">EA4K</a> - 2002-2020</h4></center><br>" +
             tr("KLog is a free logbook for hamradio operators.") +"<br><br><b>" +
-            tr("Please know that this is an BETA release and it may contain many bugs.<br>Backup your data before using this software!") +
+            tr("Please be aware that this is a development release and it may contain many bugs.<br>Backup your data before using this software!") +
             "</b><br><br>" +
-            tr("KLog has been fully rewritten from the 0.6.2 to be able to provide a cross-platform application that runs in the main operating systems (Linux, macOS & Windows) and provide new functionalities that KLog was not providing.") +
+            tr("Since 0.6.2, KLog has been fully rewritten to provide a cross-platform application that runs on all major operating systems (Linux, macOS and Windows) and to support new functionality.") +
             "<br><br>" +
             tr("Please provide your review in KLog's eHam review page:") +
             "<bR>" +
-            "<a href=http://www.eham.net/reviews/detail/3118>http://www.eham.net/reviews/detail/3118</a><br><br>" +
+            "<a href=https://www.eham.net/reviews/detail/3118>https://www.eham.net/reviews/detail/3118</a><br><br>" +
             tr("Find more information and the latest release at") + "<br><a href=https://www.klog.xyz>https://www.klog.xyz</a><br><br>" +
-            tr("Author") + ": <a href=https://jaime.robles.es/klog>Jaime Robles</a>, <a href=\"https://www.qrz.com/db/ea4tv\">EA4TV</a><br><a href=mailto:jaime@robles.es>jaime@robles.es</a>";
+            tr("Author") + ": <a href=https://jaime.robles.es/klog>Jaime Robles</a>, <a href=\"https://www.qrz.com/db/ea4k\">EA4K</a><br><a href=mailto:jaime@robles.es>jaime@robles.es</a>";
 
 
     QLabel *copyRightLabel = new QLabel(description);
@@ -66,7 +55,7 @@ AboutDialog::AboutDialog(const QString tversion, QWidget *parent)
     QLabel *logoLabel4 = new QLabel;
     logoLabel4->setPixmap(pixmap);
 
-    QString author1 = QString("<tr><td>Jaime Robles</td>") + QString("<td><a href=\"https://www.qrz.com/db/ea4tv\">EA4TV</a></td>") + "<td>(2002-" + tr("today") +")" +tr("Main developer") + "</td></tr>";
+    QString author1 = QString("<tr><td>Jaime Robles</td>") + QString("<td><a href=\"https://www.qrz.com/db/ea4k\">EA4K</a></td>") + "<td>(2002-" + tr("today") +")" +tr("Main developer") + "</td></tr>";
     QString author2 = QString("<tr><td>Akihiro Koda</td>")  + QString("<td><a href=\"https://www.qrz.com/db/jl3oxr\">JL3OXR</a></td>") + "<td>(2016-2017)</td></tr>";
     QString author3 = QString("<tr><td>Andrew Goldie</td>") + QString("<td><a href=\"https://www.qrz.com/db/zl2agc\">ZL2ACG</a></td>") + "<td>(2009-2010)</td></tr>";
 
@@ -83,7 +72,7 @@ AboutDialog::AboutDialog(const QString tversion, QWidget *parent)
     QString translator7 = QString("<tr><td>Italian</td>")  + QString("<td>Simona Pisano</td>") + QString("<td><a href=\"https://www.qrz.com/db/iu5hiu\">IU5HIU</a></td></tr>");
     QString translator8 = QString("<tr><td>Japanese</td>")  + QString("<td>Akihiro Koda</td>") + QString("<td><a href=\"https://www.qrz.com/db/jl3oxr\">JL3OXR</a></td></tr>");
     QString translator9 = QString("<tr><td>Polish</td>")  + QString("<td>Piotr Ludwig</td>") + QString("<td><a href=\"https://www.qrz.com/db/la7rra\">LA7RRA</a></td></tr>");
-    QString translator10 = QString("<tr><td>Spanish</td>") + QString("<td>Jaime Robles</td>") + QString("<td><a href=\"https://www.qrz.com/db/ea4tv\">EA4TV</a></td></tr>");
+    QString translator10 = QString("<tr><td>Spanish</td>") + QString("<td>Jaime Robles</td>") + QString("<td><a href=\"https://www.qrz.com/db/ea4k\">EA4K</a></td></tr>");
 
 
     QString translatorsText = tr("Translators bring KLog into your language. They are really an important part of the KLog development team.") + "<br><br>" + tr("If KLog is still not in your language and you want to help us, you are welcome to contact us through the <a href=\"https://lists.nongnu.org/mailman/listinfo/klog-devel\">KLog development mailing list</a>!");
@@ -100,10 +89,10 @@ AboutDialog::AboutDialog(const QString tversion, QWidget *parent)
     translatorsLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
 
     QString privacy = "<center><h2>" + tr("Privacy advisory") + "</h2></h4></center><br>" +
-            tr("KLog developers have included a feature that reports some user data to the KLog server with the sole purpose of identifying the number of installed versions, to focus development in one direction or another taking into account user's needs") +
+            tr("KLog developers have included a feature that reports some user data to the KLog server with the sole purpose of identifying the number of installed versions, to focus development in one direction or another taking into account users' needs.") +
             "<br><br>" + tr("At present, the data that is provided is the following:") +
             "<ul><li>" + tr("Callsign") + "</li><li>" + tr("KLog version") + "</li><li>" + tr("Operating system") + "</li></ul><br><br><b>" +
-            tr("Be aware that you can enable/disable this feature from the Misc tab in the Setup page") + ".</b>";
+            tr("Be aware that you can enable/disable this feature from the Misc tab in the Setup page.") + "</b>";
 
     QLabel *privacyLabel = new QLabel(privacy);
     privacyLabel->setAlignment(Qt::AlignJustify);
@@ -152,7 +141,7 @@ AboutDialog::AboutDialog(const QString tversion, QWidget *parent)
     setLayout(layout);
 
 
-     //qDebug() << "AboutDialog::AboutDialog - END" << endl;
+       //qDebug() << "AboutDialog::AboutDialog - END" << endl;
 
 }
 AboutDialog::~AboutDialog()
