@@ -22,7 +22,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
  *                                                                           *
  *****************************************************************************/
 #include <QString>
@@ -30,15 +30,16 @@
 #include <QObject>
 //#include <QtGlobal>
 
-#include "dataproxy.h"
 #include "database.h"
 
 
-class DataProxy_SQLite : public DataProxy {
+class DataProxy_SQLite : public QObject
+{
     Q_OBJECT
 
 public:
-    DataProxy_SQLite(const QString _softVersion, const QString _parentFunction);
+
+    DataProxy_SQLite(const QString &_softVersion, const QString &_parentFunction);
     ~DataProxy_SQLite();
 
     QString getSoftVersion();
@@ -53,7 +54,7 @@ public:
 
     int getIdFromModeName(const QString& _modeName);
     int getIdFromBandName(const QString& _bandName);
-    int getSubModeIdFromSubMode(const QString _subModeName);
+    int getSubModeIdFromSubMode(const QString &_subModeName);
     int getModeIdFromSubModeId(const int _sm);
 
     QStringList getBands();
@@ -71,41 +72,44 @@ public:
     QString getNameFromSubModeId (const int _id);
 
     QString getSubModeFromId (const int _id);
-    QString getNameFromSubMode (const QString _sm); // Checks if a submode is deprecated TODO: CHeck if really needed
-    //QString getNameFromSubMode (const QString _sm); // DEPRECATED
-    bool isModeDeprecated (const QString _sm);
+    QString getNameFromSubMode (const QString &_sm); // Checks if a submode is deprecated TODO: CHeck if really needed
+    //QString getNameFromSubMode (const QString &_sm); // DEPRECATED
+    bool isModeDeprecated (const QString &_sm);
 
     QString getFreqFromBandId(const int _id);
     int getBandIdFromFreq(const double _n);
     QString getBandNameFromFreq(const double _n);
 
-    double getLowLimitBandFromBandName(const QString _sm);
-    double getLowLimitBandFromBandId(const QString _sm);
-    bool isThisFreqInBand(const QString _band, const QString _fr);
+    double getLowLimitBandFromBandName(const QString &_sm);
+    double getLowLimitBandFromBandId(const QString &_sm);
+    bool isThisFreqInBand(const QString &_band, const QString &_fr);
 
     int getLastQSOid();
-    bool addQSOFromWSJTX(const QString _dxcall, const double _freq, const QString _mode,
-                                 const QString _dx_grid, const QString _time_off, const QString _report_sent, const QString _report_rec,
-                                 const QString _tx_power, const QString _comments, const QString _name, const QString _time_on,
-                                 const int _dxcc, const QString _opQrz, const QString _stQrz, const QString _myLoc, const int _logN);
+    QDate getFirstQSODateFromCall (const QString &_call);  // If the callsign provided is not valid it provides the date of the first QSO
+    QDate getLastQSODateFromCall (const QString &_call);   // If the callsign provided is not valid it provides the date of the last QSO
+
+    bool addQSOFromWSJTX(const QString &_dxcall, const double _freq, const QString &_mode,
+                                 const QString &_dx_grid, const QString &_time_off, const QString &_report_sent, const QString &_report_rec,
+                                 const QString &_tx_power, const QString &_comments, const QString &_name, const QString &_time_on,
+                                 const int _dxcc, const QString &_opQrz, const QString &_stQrz, const QString &_myLoc, const int _logN);
 
     bool deleteQSO(const int _qsoId);
-    int isWorkedB4(const QString _qrz, const int _currentLog);
-    bool isThisQSODuplicated(const QString _qrz, const QString _date, const QString _time, const int _band, const int _mode);
-    int getDuplicatedQSOId(const QString _qrz, const QString _date, const QString _time, const int _band, const int _mode);
+    int isWorkedB4(const QString &_qrz, const int _currentLog);
+    bool isThisQSODuplicated(const QString &_qrz, const QString &_date, const QString &_time, const int _band, const int _mode);
+    int getDuplicatedQSOId(const QString &_qrz, const QString &_date, const QString &_time, const int _band, const int _mode);
     bool isDXCCConfirmed(const int _dxcc, const int _currentLog);
     bool isQSLReceived(const int _qsoId);
     bool isQSLSent(const int _qsoId);
 
-    bool qslSentViaDirect(const int _qsoId, const QString _updateDate);
-    bool qslSentViaBureau(const int _qsoId, const QString _updateDate);
-    bool qslRecViaBureau(const int _qsoId, const QString _updateDate);
-    bool qslRecViaBureau(const int _qsoId, const QString _updateDate, const bool _queueSentQSL);
-    bool qslRecViaDirect(const int _qsoId, const QString _updateDate);
-    bool qslRecViaDirect(const int _qsoId, const QString _updateDate, const bool _queueSentQSL);
-    bool qslSentAsRequested(const int _qsoId, const QString _updateDate);
-    bool qslRecAsRequested(const int _qsoId, const QString _updateDate);
-    bool setClubLogSent(const int _qsoId, const QString _st, const QString _updateDate);
+    bool qslSentViaDirect(const int _qsoId, const QString &_updateDate);
+    bool qslSentViaBureau(const int _qsoId, const QString &_updateDate);
+    bool qslRecViaBureau(const int _qsoId, const QString &_updateDate);
+    bool qslRecViaBureau(const int _qsoId, const QString &_updateDate, const bool _queueSentQSL);
+    bool qslRecViaDirect(const int _qsoId, const QString &_updateDate);
+    bool qslRecViaDirect(const int _qsoId, const QString &_updateDate, const bool _queueSentQSL);
+    bool qslSentAsRequested(const int _qsoId, const QString &_updateDate);
+    bool qslRecAsRequested(const int _qsoId, const QString &_updateDate);
+    bool setClubLogSent(const int _qsoId, const QString &_st, const QString &_updateDate);
 
     bool isHF(const int _band);
     bool isWARC(const int _band);
@@ -119,11 +123,11 @@ public:
     QString getCallFromId(const int _qsoId);
     QStringList getClubLogRealTimeFromId(const int _qsoId);
     // Complete with previous
-    QString getNameFromQRZ(const QString _call);
-    QString getQTHFromQRZ(const QString _call);
-    QString getLocatorFromQRZ(const QString _call);
-    QString getIOTAFromQRZ(const QString _call);
-    QString getQSLViaFromQRZ(const QString _call);
+    QString getNameFromQRZ(const QString &_call);
+    QString getQTHFromQRZ(const QString &_call);
+    QString getLocatorFromQRZ(const QString &_call);
+    QString getIOTAFromQRZ(const QString &_call);
+    QString getQSLViaFromQRZ(const QString &_call);
     // /Complete with previous
 
     bool updateAwardDXCC();
@@ -131,25 +135,33 @@ public:
 
 
     //LOTW
+    bool lotwSentQueue(const QString &_updateDate, const int _currentLog);          // Mark LOTW QSL SENT as Q (Queued)
+    bool lotwSentYes(const QString &_updateDate, const int _currentLog, const QString &_station);         // Update LOTW QSL SENT marked as Q as Y (Queued)
+    bool lotwSentQSOs(const QList<int> &_qsos);
+    int lotwUpdateQSLReception (const QString &_call, const QString &_qso_date, const QString &_time_on, const QString &_band, const QString &_mode, const QString &_qslrdate);
+    QList<int> getQSOsListLoTWNotSent(const QString &_stationCallsign, const QDate &_startDate, const QDate &_endDate, bool _justQueued=true);
+    QStringList getQSODetailsForLoTWDownload(const int _id);
 
-    int getContinentIdFromContinentShortName(const QString _n);
+    int getContinentIdFromContinentShortName(const QString &_n);
     QString getContinentShortNameFromEntity(const int _n);
     int getContinentIdFromEntity(const int _n);
     QStringList getContinentShortNames();
-    bool isValidContinentShortName(const QString _n);
+    bool isValidContinentShortName(const QString &_n);
+    bool isValidDXCC(const int _e);
 
-    int getCQzFromPrefix(const QString _p);
+    int getCQzFromPrefix(const QString &_p);
     int getCQzFromEntity(const int _n);
     int getITUzFromEntity(const int _n);
-    int getITUzFromPrefix(const QString _p);
+    int getITUzFromPrefix(const QString &_p);
     QString getEntityNameFromId(const int _n);
-    int getEntityIdFromName(const QString _e);
+    int getEntityIdFromName(const QString &_e);
     QString getEntityMainPrefix(const int _entityN);
+    int getEntityIdFromMainPrefix(const QString &_e);
     bool isNewCQz(int _c);
     bool isNewEntity(int _e);
     double getLongitudeFromEntity(const int _e);
     double getLatitudeFromEntity(const int _e);
-    int getDXCCFromPrefix(const QString _p);
+    int getDXCCFromPrefix(const QString &_p);
     QString getEntityPrefixes(const int _enti);
     QStringList getEntitiesNames();
     QStringList getEntitiesIds();
@@ -159,8 +171,6 @@ public:
     QStringList getOperatingYears(const int _currentLog);
     void compressDB();
     bool unMarkAllQSO();            // Unmarks all the marked QSO
-    bool lotwSentQueue(const QString _updateDate, const int _currentLog);          // Mark LOTW QSL SENT as Q (Queued)
-    bool lotwSentYes(const QString _updateDate, const int _currentLog, const QString _station);         // Update LOTW QSL SENT marked as Q as Y (Queued)
 
     bool clearLog();
 
@@ -178,10 +188,10 @@ public:
     int getHowManyConfirmedQSLInLog(const int _log);
     int getHowManyQSLSentInLog(const int _log);
 
-    int getQSOsWithContinent(const QString _cont, const int _logNumber);
+    int getQSOsWithContinent(const QString &_cont, const int _logNumber);
 
-    int getQSOsInBand(const QString _band, const int _log);
-    int getQSOsInMode(const QString _mode, const int _log);
+    int getQSOsInBand(const QString &_band, const int _log);
+    int getQSOsInMode(const QString &_mode, const int _log);
 
     // Stats - end
 
@@ -191,34 +201,34 @@ public:
     QStringList getContestNames();
     QStringList getContestCat(const int _catn);
     QStringList getContestOverlays();
-    int getContestTypeN(const int _co, const int _catop, const int _catas, const int _catpo, const int _catba, const int _catov, const int _catmo);
-    QStringList getDataFromContestType(const int _n);
-    int getLogTypeNumber(const QString _logType);
-    QString getLogTypeName(const int _logType);
-    QString getLogTypeOfUserLog(const int _logN);
+    //int getContestTypeN(const int _co, const int _catop, const int _catas, const int _catpo, const int _catba, const int _catov, const int _catmo);
+    //QStringList getDataFromContestType(const int _n);
+    //int getLogTypeNumber(const QString &_logType);
+    //QString getLogTypeName(const int _logType);
+    //QString getLogTypeOfUserLog(const int _logN);
     int getLogNumberFromQSOId(const int _qsoId);
 
     QStringList getBandNames();
     QStringList getPropModeList();
 
     bool clearSatList();
-    bool addSatellite(const QString _arrlId, const QString _name, const QString _downLink, const QString _upLink, const QString _mode, int id = -1);
-    int getDBSatId(const QString _arrlId);
+    bool addSatellite(const QString &_arrlId, const QString &_name, const QString &_downLink, const QString &_upLink, const QString &_mode, int id = -1);
+    int getDBSatId(const QString &_arrlId);
     QStringList getSatellitesList();   
-    QString getSatelliteUplink(const QString _sat);
-    QString getSatelliteDownlink(const QString _sat);
-    QString getSatelliteMode(const QString _sat);
-    QString getSatelliteFullUplink(const QString _sat);
-    QString getSatelliteFullDownlink(const QString _sat);
-    QString getSatelliteFullMode(const QString _sat);
-    QString getSatelliteName(const QString _sat);
+    QString getSatelliteUplink(const QString &_sat);
+    QString getSatelliteDownlink(const QString &_sat);
+    QString getSatelliteMode(const QString &_sat);
+    QString getSatelliteFullUplink(const QString &_sat);
+    QString getSatelliteFullDownlink(const QString &_sat);
+    QString getSatelliteFullMode(const QString &_sat);
+    QString getSatelliteName(const QString &_sat);
     QString getSateliteArrlIdFromId(const int _id);
     QStringList getQSLRcvdList();
     QStringList getQSLSentList();
     QStringList getClubLogStatusList();
     QStringList getQSLViaList();
 
-    QStringList getValidCatOptions(const int _currentCat, const int _lowerCa);
+    //QStringList getValidCatOptions(const int _currentCat, const int _lowerCa);
 
     bool fillEmptyDXCCInTheLog();
 
@@ -230,7 +240,7 @@ public:
     QString getOperatorsFromLog(const int _log);
     QString getCommentsFromLog(const int _log);
     QString getLogDateFromLog(const int _log);
-    QString getLogTypeNFromLog(const int _log);
+    //QString getLogTypeNFromLog(const int _log);
     bool addNewLog (const QStringList _qs);
     bool doesThisLogExist(const int _log);
 
@@ -241,10 +251,10 @@ public:
 
 
 
-    void getFoundInLog(const QString _txt, const int _log=-1);
+    void getFoundInLog(const QString &_txt, const int _log=-1);
 
-    //bool queryPrepare(const QString _query);
-    //bool queryBind(const QString _field, const QString value);
+    //bool queryPrepare(const QString &_query);
+    //bool queryBind(const QString &_field, const QString &value);
     //bool queryExec();
 
 private:
@@ -252,10 +262,10 @@ private:
     DataBase *db;
     QStringList sortBandIdBottonUp(const QStringList _qs);
     double getFreqFromRange(QString _fr); //May even receive: 145.900-146.00 and should return the mid in the range (145.950)
-    QStringList getColumnNamesFromTable(const QString _tableName);
+    QStringList getColumnNamesFromTable(const QString &_tableName);
 
-    int getPrefixId(const QString _qrz);
-    QString changeSlashAndFindPrefix(const QString _qrz);
+    int getPrefixId(const QString &_qrz);
+    QString changeSlashAndFindPrefix(const QString &_qrz);
 
     bool searching;
     int executionN;
@@ -268,5 +278,4 @@ signals:
     void queryError(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery); // To alert about any failed query execution
 
 };
-
 #endif // DATAPROXY_SQLITE_H
