@@ -20,33 +20,37 @@ email                : jaime@robles.es
 *    GNU General Public License for more details.                           *
 *                                                                           *
 *    You should have received a copy of the GNU General Public License      *
-*    along with KLog.  If not, see <http://www.gnu.org/licenses/>.          *
+*    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
 *                                                                           *
 *****************************************************************************/
 #include "dxcluster.h"
 
-DXClusterWidget::DXClusterWidget(DataProxy *dp, QWidget *parent)
+DXClusterWidget::DXClusterWidget(DataProxy_SQLite *dp, QWidget *parent)
           : QWidget(parent)
 {
-     //qDebug() << "DXClusterWidget::DXClusterWidget" << endl;
+       //qDebug() << "DXClusterWidget::DXClusterWidget" << endl;
     dataProxy = dp;
     constrid = 1;
     awards = new Awards(dataProxy, Q_FUNC_INFO);
+    util = new Utilities;
+    saveSpotsFile = new QFile();
 
 
     initClass();
-     //qDebug() << "DXClusterWidget::DXClusterWidget - END" << endl;
+       //qDebug() << "DXClusterWidget::DXClusterWidget - END" << endl;
 }
 
-DXClusterWidget::DXClusterWidget(DataProxy *dp, const QString &clusterToConnect, const int portToConnect, QWidget *parent)
+DXClusterWidget::DXClusterWidget(DataProxy_SQLite *dp, const QString &clusterToConnect, const int portToConnect, QWidget *parent)
           : QWidget(parent)
 {
-    //qDebug() << "DXClusterWidget::DXClusterWidget2" << clusterToConnect << QString::number(portToConnect) << endl;
+      //qDebug() << "DXClusterWidget::DXClusterWidget2" << clusterToConnect << QString::number(portToConnect) << endl;
    constrid = 2;
+   util = new Utilities;
+   saveSpotsFile = new QFile();
 
     initClass();
     server = clusterToConnect;
-    port = portToConnect;
+    port = quint16(portToConnect);
 
     dxSpotColor.setNamedColor("slategrey");
     //defaultColor.setNamedColor("slategrey");
@@ -99,7 +103,7 @@ DXClusterWidget::DXClusterWidget(DataProxy *dp, const QString &clusterToConnect,
     addData();
 
      //TESTADDSPOT();
-     //qDebug() << "DXClusterWidget::DXClusterWidget2 - END"  << endl;
+       //qDebug() << "DXClusterWidget::DXClusterWidget2 - END"  << endl;
 
 }
 
@@ -117,11 +121,13 @@ void DXClusterWidget::initClass()
     showann = true;
     showwwv = true;
     showwcy = true;
+    saveSpots = false;    
     myQrz = QString();
     currentLog = 0;
+    saveSpotsFile->setFileName(util->getSaveSpotsLogFile());
 }
 
-void DXClusterWidget::setMyQRZ(const QString _qrz)
+void DXClusterWidget::setMyQRZ(const QString &_qrz)
 {
     if (_qrz.length()>2)
     {
@@ -132,7 +138,7 @@ void DXClusterWidget::setMyQRZ(const QString _qrz)
 
 void DXClusterWidget::addData()
 {
-     //qDebug() << "DXClusterWidget::addData " << endl;
+       //qDebug() << "DXClusterWidget::addData " << endl;
 
     /*
                 QTreeWidgetItem *item = new QTreeWidgetItem(searchResultsTreeWidget);
@@ -147,21 +153,21 @@ void DXClusterWidget::addData()
                 item->setToolTip(6, aux);
 */
 
-
     dxClusterSpotItem * item = new dxClusterSpotItem(dxClusterListWidget, tr("Click on connect to connect to the DX-Cluster"), awards->getDefaultColor());
 
 
+
 }
 
 DXClusterWidget::~DXClusterWidget()
 {
-     //qDebug() << "DXClusterWidget::~DXClusterWidget" << endl;
+       //qDebug() << "DXClusterWidget::~DXClusterWidget" << endl;
 }
 
 
 void DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked( QListWidgetItem * item )
 {
-    //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: " << item->text() << endl;
+      //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: " << item->text() << endl;
 
     QStringList ql;
     ql.clear();
@@ -169,31 +175,31 @@ void DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked( QListWidgetIt
     if (item)
     {
         ql = readItem(item);
-         //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: Length: " << QString::number(ql.length())  << endl;
+           //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: Length: " << QString::number(ql.length())  << endl;
         if (ql.length()==2)
         {
             ql << "double";
-             //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: EMMITED"  << endl;
+               //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: EMMITED"  << endl;
             emit dxspotclicked(ql);
         }
         else
         {
-             //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: NOT EMMITED-1"  << endl;
+               //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: NOT EMMITED-1"  << endl;
         }
     }
     else
     {
-         //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: NOT EMMITED-2 (no item)"  << endl;
+           //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: NOT EMMITED-2 (no item)"  << endl;
     }
 
 }
 
 void DXClusterWidget::connectToDXCluster()
 {
-     //qDebug() << "DXClusterWidget::connectToDXCluster" << endl;
+       //qDebug() << "DXClusterWidget::connectToDXCluster" << endl;
     if (dxClusterConnected)
     {
-         //qDebug() << "DXClusterWidget::connectToDXCluster: - Already connected!!" << endl;
+           //qDebug() << "DXClusterWidget::connectToDXCluster: - Already connected!!" << endl;
         return; // If we are connected we don't want to start another connection
     }
 
@@ -203,17 +209,18 @@ void DXClusterWidget::connectToDXCluster()
     connect(tcpSocket, SIGNAL(disconnected()), SLOT(slotClusterSocketConnectionClosed()) );
     connect(inputCommand, SIGNAL(returnPressed()), this, SLOT(slotClusterSendToServer()) );
     connect(clearButton, SIGNAL(clicked()), this, SLOT(slotClusterClearLineInput()) );
-
+    //openFile(); // This functions opens the file to save the DX-Cluster activity. The file will be closed when the DX is disconnected.
     tcpSocket->connectToHost( server, port );
     dxClusterListWidget->setSortingEnabled (false);
 
     dxClusterSpotItem * item = new dxClusterSpotItem(dxClusterListWidget, tr("Trying to connect to the server") + "\n", awards->getDefaultColor());
+
 }
 
 
 void DXClusterWidget::slotClusterDisplayError(QAbstractSocket::SocketError socketError)
 {
-     //qDebug() << "DXClusterWidget:displayError:" << endl;
+       //qDebug() << "DXClusterWidget:displayError:" << endl;
      switch (socketError) {
      case QAbstractSocket::RemoteHostClosedError:
          break;
@@ -238,76 +245,76 @@ void DXClusterWidget::slotClusterDisplayError(QAbstractSocket::SocketError socke
 
  }
 
-bool DXClusterWidget::checkIfNeedsToBePrinted(const QString _DXEntity, int const _band, const int _mode)
+bool DXClusterWidget::checkIfNeedsToBePrinted(const QString &_DXEntity, int const _band, const int _mode)
 {
-    //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: " << _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
+      //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: " << _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
     QStringList qs;
     qs.clear();
     qs << _DXEntity << QString::number(_band) << QString::number(_mode)  << QString::number(currentLog);
     //bool isConfirmed = false;
     bool status = awards->isThisSpotConfirmed (qs);
 
-    //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: Status: " << _DXEntity << "/" << QString::number(status);
+      //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: Status: " << _DXEntity << "/" << QString::number(status);
 
     if (!showconfirmed)
     {
-        //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is confirmed? ("<< QString::number(status)<< ")" << endl;
+          //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is confirmed? ("<< QString::number(status)<< ")" << endl;
         if (status)
         {
-            //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: It is confirmed: DON'T' print: " << _DXEntity <<"/" << dataProxy->getNameFromBandId(_band) << endl;
+              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: It is confirmed: DON'T' print: " << _DXEntity <<"/" << dataProxy->getNameFromBandId(_band) << endl;
             return false;
         }
     }
 
     if (!showhf)
     {
-        //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is HF?" << endl;
+          //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is HF?" << endl;
         if (dataProxy->isHF(_band))
         {
-            //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: Not showing HF but... is it WARC?" << endl;
+              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: Not showing HF but... is it WARC?" << endl;
             if ( (showwarc) && dataProxy->isWARC(_band) )
             {
-                //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: Not showing HF but... is WARC, print!" << endl;
+                  //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: Not showing HF but... is WARC, print!" << endl;
                 return true;
             }
 
-            //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is HF: DON'T print: "<< _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
+              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is HF: DON'T print: "<< _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
             return false;
         }
         else
         {
-            //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT HF" << endl;
+              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT HF" << endl;
         }
     }
 
     if (!showwarc)
     {
-        //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is WARC?" << endl;
+          //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is WARC?" << endl;
         if (dataProxy->isWARC(_band))
         {
-            //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is WARC, DON'T print: "<< _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
+              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is WARC, DON'T print: "<< _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
             return false;
         }
         else
         {
-            //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT WARC" << endl;
+              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT WARC" << endl;
         }
     }
 
     if (!showvhf)
     {
-         //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is VHF?" << endl;
+           //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is VHF?" << endl;
         if (dataProxy->isVHF(_band))
         {
-             //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is VHF, DON'T print: "<< _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
+               //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is VHF, DON'T print: "<< _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
             return false;
         }
         else
         {
-             //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT VHF " << endl;
+               //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT VHF " << endl;
         }
     }
-     //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: returns TRUE and will be printed: " << _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
+       //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: returns TRUE and will be printed: " << _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
     return true;
 }
 
@@ -326,7 +333,7 @@ void DXClusterWidget::setCurrentLog(const int _log)
 
 void DXClusterWidget::slotClusterDataArrived()
 {
-    //qDebug() << "DXClusterWidget::slotClusterDataArrived" << endl;
+      //qDebug() << "DXClusterWidget::slotClusterDataArrived" << endl;
     QStringList qs;
     QString dxClusterString;
     QString dxCall;
@@ -336,9 +343,11 @@ void DXClusterWidget::slotClusterDataArrived()
     //bool isADXSpot = false;
     int dxEntity = -1;
 
-    while ( tcpSocket->canReadLine() ) {
+    while ( tcpSocket->canReadLine() )
+    {
         dxClusterString =  tcpSocket->readLine();
         dxClusterString = dxClusterString.trimmed();
+        saveSpot(dxClusterString);
 
         QStringList tokens = dxClusterString.split(" ", QString::SkipEmptyParts);
         if (tokens.size()<2){
@@ -346,18 +355,18 @@ void DXClusterWidget::slotClusterDataArrived()
         }
         // It is a "DX de SP0TTER FREC DXCALL"
         //0 = DX, 1 = de, 2 = spotter, 3 = Freq, 4 = dxcall, 5 = comment
-        //qDebug() << "DXClusterWidget::slotClusterDataArrived: " << "DXCLUSTER->" << dxClusterString << "\nTOKENS: " << tokens << endl;
+          //qDebug() << "DXClusterWidget::slotClusterDataArrived: " << "DXCLUSTER->" << dxClusterString << "\nTOKENS: " << tokens << endl;
 
         if ((tokens[0] == "DX") && (tokens[1] == "de"))
         {
-            //qDebug() << "******************** DXClusterWidget::slotClusterDataArrived: DX DE" << endl;
+              //qDebug() << "******************** DXClusterWidget::slotClusterDataArrived: DX DE" << endl;
             //isADXSpot = true;
             QString spotter = tokens[2];
             spotter.truncate(spotter.size() - 1);
             dxFrequency = tokens[3];
             // Convert KHz to MHz...
             //dxFrequency = QString::number(abs (dxFrequency.toFloat())/1000);
-            dxFrequency = QString::number( (dxFrequency.toFloat())/1000);
+            dxFrequency = QString::number( (dxFrequency.toDouble())/1000);
             dxCall = tokens[4];
             dxEntity = world->getQRZARRLId(dxCall);
             //
@@ -367,7 +376,7 @@ void DXClusterWidget::slotClusterDataArrived()
             qs.clear();
             //spotBand = QString::number(world->getBandIdFromFreq(  dxFrequency  ) );
             qs << QString::number(dxEntity) << spotBand << "-1" << QString::number(currentLog) ;
-             //qDebug() << "DXClusterWidget::slotClusterDataArrived: Calling-2: " << QString::number(dxEntity) << endl;
+               //qDebug() << "DXClusterWidget::slotClusterDataArrived: Calling-2: " << QString::number(dxEntity) << endl;
             dxSpotColor = awards->getQRZDXStatusColor(qs);
             if  (showDxMarathon)
             {
@@ -378,29 +387,29 @@ void DXClusterWidget::slotClusterDataArrived()
             }
 
 
-            //qDebug() << "DX de ->" << "Spotter: " << spotter << "Freq: "<< dxFrequency << "DX: " << dxCall << endl;
+              //qDebug() << "DX de ->" << "Spotter: " << spotter << "Freq: "<< dxFrequency << "DX: " << dxCall << endl;
 
         }
         else if ((tokens[0] == "To") && (tokens[1] == "ALL"))
         {
-            //qDebug() << "DXClusterWidget::slotClusterDataArrived: TO ALL" << endl;
+              //qDebug() << "DXClusterWidget::slotClusterDataArrived: TO ALL" << endl;
             dxSpotColor = awards->getDefaultColor();
         }
         else if ( (dxClusterString.length()>=5) && (world->checkQRZValidFormat(tokens[1])) && (tokens[0]!="login:"))
         { // Freq / DXCall / Date // time
            //_qs << QRZ << Freq in MHz << lognumber;
-           //qDebug() << "DXClusterWidget::slotClusterDataArrived: LENGTH >= 5" << endl;
-           //qDebug() << "DXClusterWidget::slotClusterDataArrived: token0=" << tokens[0] << " / token1=" << tokens[1] << endl;
+             //qDebug() << "DXClusterWidget::slotClusterDataArrived: LENGTH >= 5" << endl;
+             //qDebug() << "DXClusterWidget::slotClusterDataArrived: token0=" << tokens[0] << " / token1=" << tokens[1] << endl;
 
             //isADXSpot = true;
             dxCall = tokens[1];
             dxFrequency = tokens[0];
-            dxFrequency = QString::number( (dxFrequency.toFloat())/1000);
+            dxFrequency = QString::number( (dxFrequency.toDouble())/1000);
 
             qs.clear();
             spotBand = QString::number(dataProxy->getBandIdFromFreq(  dxFrequency.toDouble()  ) );
             dxEntity = world->getQRZARRLId(dxCall);
-             //qDebug() << "DXClusterWidget::slotClusterDataArrived: Calling-1: " << QString::number(dxEntity) << endl;
+               //qDebug() << "DXClusterWidget::slotClusterDataArrived: Calling-1: " << QString::number(dxEntity) << endl;
             qs << QString::number(dxEntity) << spotBand << "-1" << QString::number(currentLog) ;
             dxSpotColor = awards->getQRZDXStatusColor(qs);
             if (showDxMarathon)
@@ -415,7 +424,7 @@ void DXClusterWidget::slotClusterDataArrived()
         }
         else
         {
-             //qDebug() << "DXClusterWidget::slotClusterDataArrived: DEFAULT" << endl;
+               //qDebug() << "DXClusterWidget::slotClusterDataArrived: DEFAULT" << endl;
             dxSpotColor = awards->getDefaultColor();
         }
 
@@ -424,12 +433,12 @@ void DXClusterWidget::slotClusterDataArrived()
         //qs << dxCall << spotBand << "0";
 
         //dxSpotColor = awards->getQRZDXStatusColor(qs);
-         //qDebug() << "DXClusterWidget::slotClusterDataArrived: Call/dxSpotColor: " << dxCall <<"/"<< dxSpotColor.name() << endl;
+           //qDebug() << "DXClusterWidget::slotClusterDataArrived: Call/dxSpotColor: " << dxCall <<"/"<< dxSpotColor.name() << endl;
         //dxClusterSpotItem * item = new dxClusterSpotItem(dxClusterListWidget, dxClusterString, dxSpotColor);
         //TODO: Change the "-1" by the mode
         if (!checkIfNeedsToBePrinted(QString::number(dxEntity), spotBand.toInt(), -1))
         {
-            //qDebug() << "DXClusterWidget::slotClusterDataArrived - Not to be printed!: " << dxCall << endl;
+              //qDebug() << "DXClusterWidget::slotClusterDataArrived - Not to be printed!: " << dxCall << endl;
             return;
         }
 
@@ -470,15 +479,15 @@ void DXClusterWidget::slotClusterDataArrived()
         //dxClusterListWidget->insertItem(0,item);
     }
 
-     //qDebug() << "--------------------- DXClusterWidget::slotClusterDataArrived: " << dxClusterString << endl;
+       //qDebug() << "--------------------- DXClusterWidget::slotClusterDataArrived: " << dxClusterString << endl;
 
-    //qDebug() << "DXClusterWidget::slotClusterDataArrived: " << dxClusterString << endl;
+      //qDebug() << "DXClusterWidget::slotClusterDataArrived: " << dxClusterString << endl;
 
 }
 
 void DXClusterWidget::slotClusterSocketConnected()
 {
-     //qDebug() << "DXClusterWidget::slotClusterSocketConnected" << endl;
+       //qDebug() << "DXClusterWidget::slotClusterSocketConnected" << endl;
 
     QListWidgetItem *item = new QListWidgetItem();
     item->setForeground(QBrush(awards->getDefaultColor()));
@@ -523,7 +532,7 @@ void DXClusterWidget::slotClusterSocketConnected()
 
 void DXClusterWidget::slotClusterSocketConnectionClosed()
 {
-     //qDebug() << "DXClusterWidget::slotClusterSocketConnectionClosed" << endl;
+       //qDebug() << "DXClusterWidget::slotClusterSocketConnectionClosed" << endl;
     QListWidgetItem *item = new QListWidgetItem();
     item->setForeground(QBrush(awards->getDefaultColor()));
     item->setText(tr("Connection closed by the server"));
@@ -539,7 +548,7 @@ void DXClusterWidget::slotClusterSocketConnectionClosed()
 
 void DXClusterWidget::slotClusterSendToServer()
 {
-     //qDebug() << "DXClusterWidget::slotClusterSendToServer()" << endl;
+       //qDebug() << "DXClusterWidget::slotClusterSendToServer()" << endl;
     if (!dxClusterConnected)
     {
 
@@ -548,7 +557,7 @@ void DXClusterWidget::slotClusterSendToServer()
     }
     if ( inputCommand ->text().length() < 1 )
     {
-         //qDebug() << "DXClusterWidget::slotClusterSendToServer() - Vacio..." << endl;
+           //qDebug() << "DXClusterWidget::slotClusterSendToServer() - Vacio..." << endl;
         QTextStream os(tcpSocket);
         os << "bye\n";
         return;
@@ -561,7 +570,7 @@ void DXClusterWidget::slotClusterSendToServer()
 
 void DXClusterWidget::slotClusterClearLineInput()
 {
-     //qDebug() << "DXClusterWidget::slotClusterClearLineInput" << endl;
+       //qDebug() << "DXClusterWidget::slotClusterClearLineInput" << endl;
 
     if ( ((inputCommand->text()).length()) <= 0 )
     {
@@ -583,7 +592,7 @@ void DXClusterWidget::slotClusterClearLineInput()
 
 void DXClusterWidget::slotClusterInputTextChanged()
 {
-     //qDebug() << "DXClusterWidget::slotClusterInputTextChanged" << endl;
+       //qDebug() << "DXClusterWidget::slotClusterInputTextChanged" << endl;
 
     if ( ((inputCommand->text()).length()) <= 0 )
     {
@@ -599,9 +608,9 @@ void DXClusterWidget::slotClusterInputTextChanged()
     {}
 }
 
-void DXClusterWidget::setColors (const QString _newOne, const QString _needed, const QString _worked, const QString _confirmed, const QString _default)
+void DXClusterWidget::setColors (const QString &_newOne, const QString &_needed, const QString &_worked, const QString &_confirmed, const QString &_default)
 {
-     //qDebug() << "DXClusterWidget::setColors: " << _newOne << "/" << _needed << "/" << _worked << "/" << _confirmed << "/" << _default << endl;
+       //qDebug() << "DXClusterWidget::setColors: " << _newOne << "/" << _needed << "/" << _worked << "/" << _confirmed << "/" << _default << endl;
     // Just to pass the colors to the awards class
     awards->setColors(_newOne,  _needed, _worked,  _confirmed, _default);
 
@@ -609,7 +618,7 @@ void DXClusterWidget::setColors (const QString _newOne, const QString _needed, c
 
 void DXClusterWidget::setDXClusterSpotConfig(bool _showhf, bool _showvhf, bool _showwarc, bool _showworked, bool _showconfirmed, bool _showann, bool _showwwv, bool _showwcy )
 {
-     //qDebug() << "DXClusterWidget::setDXClusterSpotConfig " << endl;
+       //qDebug() << "DXClusterWidget::setDXClusterSpotConfig " << endl;
 
     showhf = _showhf;
     showvhf = _showvhf;
@@ -623,7 +632,7 @@ void DXClusterWidget::setDXClusterSpotConfig(bool _showhf, bool _showvhf, bool _
 
 void DXClusterWidget::slotClusterDXClusterWidgetItemSelected()
 {
-     //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemSelected " << endl;
+       //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemSelected " << endl;
     QListWidgetItem * item = dxClusterListWidget->currentItem();
 
     QStringList ql;
@@ -643,7 +652,7 @@ void DXClusterWidget::slotClusterDXClusterWidgetItemSelected()
 
 void DXClusterWidget::slotClusterDXClusterWidgetItemEntered( QListWidgetItem * item )
 {
-     //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemEntered" << endl;
+       //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemEntered" << endl;
 /*
     This code comes from slotClusterDXClusterWidgetItemDoubleClicked
 */
@@ -678,7 +687,7 @@ bool DXClusterWidget::isConnected()
 
 QStringList DXClusterWidget::readItem(QListWidgetItem * item)
 {
-     //qDebug() << "DXClusterWidget::readItem" << endl;
+      //qDebug() << "DXClusterWidget::readItem" << endl;
 
     QStringList fields;
     QString dxClusterString;
@@ -689,17 +698,17 @@ QStringList DXClusterWidget::readItem(QListWidgetItem * item)
     if (item) {
 
         fields.clear();
-        dxClusterString = ((item->data(0)).toString()).simplified();
+        dxClusterString = ((item->data(0)).toString()).simplified();        
         fields << dxClusterString.split(" ");
 
         (fields.at(0)).toFloat(&FirstFrecOK); // Just to see if the first string is a frecuency
 
         if ( (fields.at(0) == "DX" ) && (fields.at(1) == "de" ) )
-        { // DX de EA4TV: 21200.1 EA0JC The comment 1550
+        { // DX de EA4K: 21200.1 EA0JC The comment 1550
 
             if ( world->getQRZARRLId(fields.at(4))> 0 )
             {
-                 //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: ARRLid: " << QString::number(world->getQRZARRLId(fields.at(4)))  << endl;
+                   //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: ARRLid: " << QString::number(world->getQRZARRLId(fields.at(4)))  << endl;
                 dxCallsign = (fields.at(4)).toUpper();
                 (fields.at(3)).toFloat(&FirstFrecOK);
                 if (FirstFrecOK)
@@ -721,15 +730,15 @@ QStringList DXClusterWidget::readItem(QListWidgetItem * item)
             else
             { // The call is not from a valid country
               // TODO: if it is from a new entity/prefix it would not work.
-                 //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: Entity not valid"  << endl;
+                   //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: Entity not valid"  << endl;
                 dxCallsign.clear();
                 dxFreq.clear();
                 fields.clear();
             }
         }
         //else if (( isAFrecuency(fields.at(0) ) ) && ( isACall(fields.at(1)) ) )
-        else if ( (((fields.at(0)).toFloat()) > 0.0 )&& ( world->getQRZARRLId(fields.at(1))> 0 ) )
-        { // 14205.0 EA0JC    5-Mar-2012 1500Z    <EA4TV>
+        else if ( (((fields.at(0)).toDouble()) > 0.0 )&& ( world->getQRZARRLId(fields.at(1))> 0 ) )
+        { // 14205.0 EA0JC    5-Mar-2012 1500Z    <EA4K>
 
             dxCallsign = (fields.at(1)).toUpper();
             dxFreq = fields.at(0);
@@ -755,8 +764,8 @@ QStringList DXClusterWidget::readItem(QListWidgetItem * item)
 void DXClusterWidget::setDXClusterServer(const QString &clusterToConnect, const int portToConnect)
 {
     server = clusterToConnect;
-    port = portToConnect;
-     //qDebug() << "DXClusterWidget::setDXClusterServer: " << server << ":"<< QString::number(port)  << endl;
+    port = quint16(portToConnect);
+       //qDebug() << "DXClusterWidget::setDXClusterServer: " << server << ":"<< QString::number(port)  << endl;
 }
 
 void DXClusterWidget::setDXMarathon (const bool _enable)
@@ -764,10 +773,64 @@ void DXClusterWidget::setDXMarathon (const bool _enable)
     showDxMarathon = _enable;
 }
 
+void  DXClusterWidget::setSaveSpots (const bool _enable)
+{
+    saveSpots = _enable;
+}
+
+bool DXClusterWidget::openFile()
+{
+    if (saveSpotsFile->isOpen())
+    {
+        return true;
+    }
+    if (!saveSpotsFile->open(QIODevice::WriteOnly | QIODevice::Text | QIODevice::Append))
+    {
+        QMessageBox msgBox;
+        msgBox.setIcon(QMessageBox::Warning);
+        QString aux = tr("It was not possible to open the file to save the DX-Spots for writing. DX-Cluster activity will not be saved!");
+        msgBox.setText(aux);
+        msgBox.setStandardButtons(QMessageBox::Ok);
+        msgBox.setDefaultButton(QMessageBox::Ok);
+        msgBox.exec();
+        return false;
+    }
+    else
+    {
+        return true;
+    }
+}
+
+void DXClusterWidget::saveSpot(const QString &_spot)
+{
+      //qDebug() << "DXClusterWidget::saveSpot: " << _spot  << endl;
+    if (!saveSpots)
+    {
+          //qDebug() << "DXClusterWidget::saveSpot: Not saving" << endl;
+        return;
+    }
+    else
+    {
+        if (openFile())
+        {
+              //qDebug() << "DXClusterWidget::saveSpot: File Open" << endl;
+            QTextStream out(saveSpotsFile);
+            //out << _spot << endl;
+            out << (QDateTime::currentDateTime()).toString("yyyy/MM/dd-hh:mm:ss") << " - " << _spot  << endl;
+            saveSpotsFile->close();
+        }
+        else {
+            {
+                  //qDebug() << "DXClusterWidget::saveSpot: File NOT Open" << endl;
+            }
+        }
+    }
+}
+
 /*
 void DXClusterWidget::TESTADDSPOT()
 {
-     //qDebug() << "DXClusterWidget::TESTADDSPOT "   << endl;
+       //qDebug() << "DXClusterWidget::TESTADDSPOT "   << endl;
     ; // Just a test spot
     QListWidgetItem *item = new QListWidgetItem();
     item->setForeground(QBrush(dxSpotColor));
@@ -775,13 +838,17 @@ void DXClusterWidget::TESTADDSPOT()
     dxClusterListWidget->insertItem(0,item);
 }
 */
+
+
+
+
 /***************************************************************************
 ** This is an auxiliary class intended to provide color to the DX-Cluster **
 ** spots.                                                                 **
 ** It may be moved to a self .h & .cpp archives                           **
 ****************************************************************************/
 dxClusterSpotItem::dxClusterSpotItem( QListWidget *parent, const QString& spot, const QColor& color ) : QListWidgetItem( parent ){
-     //qDebug() << "dxClusterSpotItem::dxClusterSpotItem - Constructor" << endl;
+       //qDebug() << "dxClusterSpotItem::dxClusterSpotItem - Constructor" << endl;
     spotColor = color;
     setText(spot);
     // Experimenting with fonts for the cluster
@@ -792,6 +859,6 @@ dxClusterSpotItem::dxClusterSpotItem( QListWidget *parent, const QString& spot,
 
 dxClusterSpotItem::~dxClusterSpotItem()
 {
-     //qDebug() << "dxClusterSpotItem::dxClusterSpotItem - Destructor" << endl;
+       //qDebug() << "dxClusterSpotItem::dxClusterSpotItem - Destructor" << endl;
 }
 
