@@ -22,7 +22,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
  *                                                                           *
  *****************************************************************************/
 #include <QObject>
@@ -42,7 +42,7 @@ public:
     explicit eLogClubLog();
     ~eLogClubLog();
 
-    void setCredentials(const QString _call, const QString _email, const QString _pass, const bool _useQSOStationCall);
+    void setCredentials(const QString &_call, const QString &_email, const QString &_pass, const bool _useQSOStationCall);
     int sendQSO(QStringList _qso);
     int deleteQSO(QStringList _qso);
     int modifyQSO (QStringList _oldQSO, QStringList _newQSO);
@@ -50,8 +50,8 @@ public:
 
 private:
     QString getClubLogAdif(const QStringList _q);
-    int sendData(const QString _q);                     //  Sends the data (http post) to ClubLog
-    QString prepareToTranslate(const QString _m);       //  Get the message and put it in a tr to be able to translate it
+    int sendData(const QString &_q);                     //  Sends the data (http post) to ClubLog
+    QString prepareToTranslate(const QString &_m);       //  Get the message and put it in a tr to be able to translate it
 
     QString call, email, pass, api, stationCallsign;
 
