@@ -23,7 +23,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.       *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.       *
  *                                                                           *
  *****************************************************************************/
 
@@ -42,7 +42,7 @@
 #include "world.h"
 #include "awards.h"
 #include "database.h"
-#include "dataproxy.h"
+#include "dataproxy_sqlite.h"
 #include "dataproxy_sqlite.h"
 #include "utilities.h"
 
@@ -55,45 +55,57 @@ enum
     DXCCEntities = 521 // http://www.adif.org/adif302.htm#Country%20Codes
 };
 
+//enum ExportMode {ModeLotW, ModeADIF};
+
 class FileManager : public QWidget
 {
     Q_OBJECT
 public:
-    FileManager(DataProxy *dp);
-    //FileManager(DataProxy *dp, const QString _klogDir);
-    FileManager(DataProxy *dp, const QString _klogDir, const QString _softVersion);
-    //FileManager(DataProxy *dp, const QString _softVersion);
+    FileManager(DataProxy_SQLite *dp);
+    //FileManager(DataProxy_SQLite *dp, const QString _klogDir);
+    FileManager(DataProxy_SQLite *dp, const QString &_klogDir, const QString &_softVersion);
+    //FileManager(DataProxy_SQLite *dp, const QString _softVersion);
     ~FileManager();
     //bool readAdif(const QString& tfileName, const int logN);
     bool adifReadLog(const QString& tfileName, const int logN);
-    bool adifLoTWReadLog(const QString& tfileName);
-    int adifLoTWLogExport(const QString& _fileName, const int _logN);
+    QList<int> adifLoTWReadLog(const QString& tfileName);
+    QList<int> adifLoTWLogExport(const QString& _fileName, const QString &_callsign, const QDate &_startDate, const QDate &_endDate, const int _logN);
+    //QList<int> adifLogExport(const QString& _fileName, const QString &_callsign, const QDate &_startDate, const QDate &_endDate, const int _logN, const bool LoTWOnly);
+    QList<int> adifLogExport(const QString& _fileName, const QString &_callsign, const QDate &_startDate, const QDate &_endDate, const int _logN, const ExportMode _em);
     bool adifLogExport(const QString& _fileName, const int _logN);
+   // QList<int> adifLogExportDates(const QString& _fileName, const QString &_callsign, const QDate &_startDate, const QDate &_endDate, const int _logN);
     bool adifLogExportMarked(const QString& _fileName);
     bool adifReqQSLExport(const QString& _fileName);
-    bool cabrilloLogExport(const QString& _fileName, const QString _contestType, const int logNconst);
-    bool modifySetupFile(const QString& _filename, QString _field, const QString _value);
-    void setVersion(const QString _version);
+    bool cabrilloLogExport(const QString& _fileName, const QString &_contestType, const int logNconst);
+    bool modifySetupFile(const QString& _filename, const QString &_field, const QString &_value);
+    void setVersion(const QString &_version);
+    QDateTime getDateTimeOfLastBackup();
+    void setStationCallSign(const QString& _st);
 
 
-private:
-    bool adifLogExportToFile(const QString& _fileName, const int _logN=0, bool justMarked = false, bool _qslRequested = false, bool _lotw=false);
+private:    
+    bool adifLogExportToFile(const QString& _fileName, const int _logN, bool justMarked, bool _qslRequested, bool _lotw);
     bool cabrilloLogExportToFile(const QString& _fileName, const int logNconst);
     bool cabrilloLogExportCQWWToFile(const QString& _fileName, const int logNconst);
     //bool adifCheckMoreThanOneLog(QFile &_f);
     int howManyLogsInFile(QFile & _f);
     bool fillHashLog(QFile & _f);
     QStringList getListOfLogsInFile(QFile & _f);
+    bool writeBackupDate();
+    bool getStationCallsignFromUser(const QString &_qrzDX, const QDate &_dt);
+
+    void showError (const QString &_txt);
 
 
-    //QString checkAndFixASCIIinADIF(const QString _data);
+    //QString checkAndFixASCIIinADIF(_data);
 
-    bool processQsoReadingADIF(const QStringList _line, const int logNumber, const bool _keepLogsInFile);
+    bool processQsoReadingADIF(const QStringList &_line, const int logNumber);//, const bool _keepLogsInFile);
     void queryPreparation(const int _logN);
 
-    bool checkADIFValidFormat(const QStringList _qs);
+    bool checkADIFValidFormat(const QStringList &_qs);
 
-    QStringList readAdifField (const QString _field);
+    QStringList readAdifField (const QString &_field);
+    // void writeAdifField(const QString &_field, const QString &_data); // It should possibly receive also the QTextStream
     QString prepareStringLog();
 
 
@@ -101,7 +113,7 @@ private:
     DataBase *db;
     //float softwareVersion;
     //DataProxy_SQLite *dataProxy;
-    DataProxy *dataProxy;//, *dataProxyPrepared;
+    DataProxy_SQLite *dataProxy;//, *dataProxyPrepared;
 
     Utilities *util;    
 
@@ -109,12 +121,14 @@ private:
 
 
     //bool printQs(const QString _q, const QStringList _line);
-    bool printQs(const QStringList _line);
+    bool printQs(const QStringList &_line);
     //int confirmed;
     QString klogDir;
     QString klogVersion;
-    //QProgressBar *progressBar;
+    QString defaultStationCallsign;
+
     bool ignoreUnknownAlways;   // When importing ADIF, ignore all unknown fields.
+    bool usePreviousStationCallsignAnswerAlways;   // When importing ADIF, ignore all unknown fields.
     bool noMoreQso;
 
     World *world;
@@ -129,7 +143,8 @@ private:
 
 
 signals:
-    void queryError(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery); // To alert about any failed query execution
+    void addQSOToList(QStringList _qso);
+    void queryError(QString _functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery); // To alert about any failed query execution
 
 };
 #endif // FILEMANAGER_H
