@@ -23,7 +23,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
  *                                                                           *
  *****************************************************************************/
 
@@ -35,32 +35,36 @@
 #include <QSqlQuery>
 #include <QSqlRecord>
 #include <QSqlRelationalDelegate>
-#include "dataproxy.h"
+#include <QDesktopServices>
+#include "dataproxy_sqlite.h"
 #include "logmodel.h"
 #include "awards.h"
 //#include "dxccstatuswidget.h"
 #include "elogclublog.h"
+//#include "logviewsortfilterproxymodel.h"
 
+//class  LogViewSortFilterProxyModel;
 
 class LogWindow : public  QWidget
 {
     Q_OBJECT
 
 public:
-    explicit LogWindow(DataProxy *dp, QWidget *parent = 0);
+    explicit LogWindow(DataProxy_SQLite *dp, QWidget *parent = nullptr);
     ~LogWindow();
     void createlogPanel(const int _currentLog);
     void clear();
     void refresh();
     void setCurrentLog(const int _currentLog);
 
-
     void qslSentViaBureau(const int _qsoId);    //Maybe this could be defined as private and call it with an action, if needed.
     void qslRecViaBureau(const int _qsoId);     //Maybe this could be defined as private and call it with an action, if needed.
     void qslRecViaDirect(const int _qsoId);
 
     bool isQSLReceived(const int _qsoId);
     bool isQSLSent(const int _qsoId);
+    //void setProxyModel (const bool _p);
+    void sortColumn(const int _c);
 
 signals:
     void actionQSODoubleClicked(const int _qsoid);
@@ -75,8 +79,6 @@ private slots:
     void slotDoubleClickLog(const QModelIndex & index);
 
     void slotRighButtonFromLog(const QPoint& pos);
-
-
     void slotQSLSentViaBureauFromLog();
     void slotQSLSentViaDirectFromLog();
     void slotQSLRecViaDirectFromLog();
@@ -84,6 +86,8 @@ private slots:
     void slotQsoDeleteFromLog();
     void slotQSOToEditFromLog();
     void slotQueryErrorManagement(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery);
+    void slotCheckQRZCom();
+    void slotCheckDXHeatCom();
 
 
 private:    
@@ -100,7 +104,7 @@ private:
     void setColumnsToDX();
 
 
-    DataProxy *dataProxy;
+    DataProxy_SQLite *dataProxy;
     LogModel *logModel;
     Awards *awards;
     //DXCCStatusWidget *dxccStatusWidget;
@@ -115,8 +119,13 @@ private:
     QAction *qslSentViaDirectFromLogAct;
     QAction *qslRecViaBureauFromLogAct;
     QAction *qslRecViaDirectFromLogAct;
+    QAction *checkQRZCOMFromLogAct;
+    QAction *checkDXHeatFromLogAct;
 
     int currentLog;
+
+   //LogViewSortFilterProxyModel *proxyModel;
+   //bool sortingThroughProxyModel;
 };
 
 
