@@ -11,7 +11,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
  *                                                                           *
  *****************************************************************************/
 
@@ -20,6 +20,8 @@
 #include <QTranslator>
 #include <cstdlib>
 #include <QTextStream>
+#include <QCoreApplication>
+#include <QCommandLineParser>
 
 //#include <QDebug>
 
@@ -31,8 +33,10 @@
 
 int main(int argc, char *argv[])
 {
-    QString version = "0.9.8.1" ;
+      //qDebug() << "KLog Main: Start! " << endl;
+      //qDebug() << "KLog Main: " << QSslSocket::supportsSsl() << QSslSocket::sslLibraryBuildVersionString() << QSslSocket::sslLibraryVersionString() << endl;
     QDir d1 = QDir();
+    QString version = "1.1";
     Utilities util = Utilities();
     QStringList arguments;
     QTextStream cout(stdout);
@@ -44,12 +48,11 @@ int main(int argc, char *argv[])
     QIcon KLogIcon(iconSt);
     QApplication::setWindowIcon(KLogIcon);
 
-
     //QApplication app(argc, argv);
     app.setApplicationName(QString("KLog"));
+
     app.setApplicationVersion(QString(version));
-
-
+      //qDebug() << "KLog Main: -10 " << endl;
     // Now we check if the user is executing from the command line
     arguments.clear();
     arguments << app.arguments();
@@ -89,16 +92,13 @@ int main(int argc, char *argv[])
 
         app.quit();
         return 0;
-
     }
 
-
-     //qDebug() << "KLog Main: Start of translation activities: "<< (QTime::currentTime()).toString("HH:mm:ss") << endl;
-     //qDebug() << "KLog Main: Detected language: " << (QLocale::system().name()).left(2) << ".qm" << endl;
+       //qDebug() << "KLog Main: Start of translation activities: "<< (QTime::currentTime()).toString("HH:mm:ss") << endl;
+        //qDebug() << "KLog Main: Detected language: " << (QLocale::system().name()).left(2) << ".qm" << endl;
     // Translations begin
         QTranslator qtTranslator;
-        qtTranslator.load("qt_" + QLocale::system().name(),
-                QLibraryInfo::location(QLibraryInfo::TranslationsPath));
+        qtTranslator.load("qt_" + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
         app.installTranslator(&qtTranslator);
         QTranslator myappTranslator;
 
@@ -106,7 +106,8 @@ int main(int argc, char *argv[])
         //QString msgOSFilePath = QString();        // The OS depending part of the message to be printed if no translation is found.
 
     #if defined(Q_OS_WIN)
-         //qDebug() << "KLog WIN " << endl;
+            //qDebug() << "KLog WIN " << endl;
+            //qDebug() << "KLog Main: -20 - WIN" << endl;
         if (QFile::exists(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) + ".qm") )
         {
             myappTranslator.load(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) + ".qm");
@@ -123,9 +124,9 @@ int main(int argc, char *argv[])
             missingTranslation = true;
             //msgOSFilePath = QCoreApplication::applicationDirPath() + "/translations/" ;
         }
-
+      //qDebug() << "KLog Main: -20 - end WIN " << endl;
     #elif defined(Q_OS_OSX)
-         //qDebug() << "KLog OSX " << endl;
+            //qDebug() << "KLog OSX " << endl;
 
         if (QFile::exists(QCoreApplication::applicationDirPath() + "/translations/klog_" +  (QLocale::system().name()).left(2) + ".qm") )
         {
@@ -143,19 +144,19 @@ int main(int argc, char *argv[])
         }
 
     #else
-        //qDebug() << "KLog OTHER OS: " << (QLocale::system()).name() << endl;
+           //qDebug() << "KLog OTHER OS: " << (QLocale::system()).name() << endl;
         if (QFile::exists("klog_" + (QLocale::system().name()).left(2) + ".qm") )
         {
             myappTranslator.load("klog_" + (QLocale::system().name()).left(2));
         }
         else if (QFile::exists("/usr/share/klog/translations/klog_" + (QLocale::system().name()).left(2) + ".qm") )
         {
-            //qDebug() << "KLog OTHER -2: " << "/usr/share/klog/klog_" + (QLocale::system().name()).left(2) << endl;
+               //qDebug() << "KLog OTHER -2: " << "/usr/share/klog/klog_" + (QLocale::system().name()).left(2) << endl;
             myappTranslator.load("/usr/share/klog/translations/klog_" + (QLocale::system().name()));
         }
         else if (QFile::exists(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) + ".qm"))
         {
-                 //qDebug() << "KLog OTHER -3: " << QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) << endl;
+                    //qDebug() << "KLog OTHER -3: " << QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) << endl;
             myappTranslator.load(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()));
         }
 
@@ -170,10 +171,10 @@ int main(int argc, char *argv[])
         }
 
     #endif
-
+      //qDebug() << "KLog Main: -40 " << endl;
         if (missingTranslation)
         {
-             //qDebug() << "KLog Main: Translation missing! " << endl;
+                //qDebug() << "KLog Main: Translation missing! " << endl;
             QMessageBox msgBox;
             QString urlTranslate = QString();
             urlTranslate = "<p><a href=\"https://translate.google.com/?sl=auto&tl=auto#en/auto/No%20translation%20files%20for%20your%20language%20have%20been%20found%20so%20KLog%20will%20be%20shown%20in%20English.%0A%0AIf%20you%20have%20the%20klog_en.qm%20file%20for%20your%20language%2C%20you%20can%20copy%20it%20in%20the%20%2Fhome%2Fdevel%2F.klog%2F%20folder%20and%20restart%20KLog%20again.%0A%0A%20If%20you%20want%20to%20help%20to%20translate%20KLog%20into%20your%20language%2C%20please%20contact%20the%20author.\">TRANSLATE</a></p>";
@@ -196,10 +197,10 @@ int main(int argc, char *argv[])
 
         }
 
-    //qDebug() << "KLog Main-1" << (QTime::currentTime()).toString("HH:mm:ss")  << endl;
+       //qDebug() << "KLog Main-1" << (QTime::currentTime()).toString("HH:mm:ss")  << endl;
 
     app.installTranslator(&myappTranslator);
-    //qDebug() << "KLog Main: End of translation activities: "<< (QTime::currentTime()).toString("HH:mm:ss") << endl;
+       //qDebug() << "KLog Main: End of translation activities: "<< (QTime::currentTime()).toString("HH:mm:ss") << endl;
     // Traslations end
 
     QString configFileName, klogDir;
@@ -207,61 +208,63 @@ int main(int argc, char *argv[])
     klogDir = util.getHomeDir();
     configFileName = util.getCfgFile();
 
-    //qDebug() << "KLog Main-10" << endl;
+       //qDebug() << "KLog Main-10" << endl;
 
-    //qDebug() << "KLog Main: Setting klog dir: " << (QTime::currentTime()).toString("HH:mm:ss")<< endl;;
+       //qDebug() << "KLog Main: Setting klog dir: " << (QTime::currentTime()).toString("HH:mm:ss")<< endl;;
     if (!QDir::setCurrent (klogDir) )
     {
-         //qDebug() << "MAIN:  KLogDir does not exist.... creating " << endl;
+            //qDebug() << "MAIN:  KLogDir does not exist.... creating " << endl;
         if (d1.mkdir(klogDir))
         {
             if (QDir::setCurrent (klogDir) )
             {
-                 //qDebug() << "MAIN:  KLogDir has just been created and pointed " << endl;
+                    //qDebug() << "MAIN:  KLogDir has just been created and pointed " << endl;
             }
             else
             {
-                 //qDebug() << "MAIN:  KLogDir has just been created and pointed FAILED! " << endl;
+                    //qDebug() << "MAIN:  KLogDir has just been created and pointed FAILED! " << endl;
             }
         }
         else
         {
-             //qDebug() << "MAIN:  KLogDir can not be created?? " << endl;
+                //qDebug() << "MAIN:  KLogDir can not be created?? " << endl;
         }
     }
     else
     {
-         //qDebug() << "MAIN:  KLogDir already existed!! " << endl;
+            //qDebug() << "MAIN:  KLogDir already existed!! " << endl;
     }
-   //qDebug() << "KLog Main: Setting klog dir - finished: " << (QTime::currentTime()).toString("HH:mm:ss") << endl;
+      //qDebug() << "KLog Main: Setting klog dir - finished: " << (QTime::currentTime()).toString("HH:mm:ss") << endl;
 
-    //qDebug() << "KLog Main: Setting config file: " << (QTime::currentTime()).toString("HH:mm:ss")  << endl;
+       //qDebug() << "KLog Main: Setting config file: " << (QTime::currentTime()).toString("HH:mm:ss")  << endl;
+    QPixmap pixmap(":img/klog_512x512.png");
+        //qDebug() << "KLog Main-51" << (QTime::currentTime()).toString("HH:mm:ss") << endl;
+    QSplashScreen splash(pixmap);
     if(!QFile::exists(configFileName))
     {
-         //qDebug() << "MAIN:  Starting wizard... " << endl;
+            //qDebug() << "MAIN:  Starting wizard... " << endl;
 
         StartWizard *wizard = new StartWizard(klogDir, version);
         wizard->setModal(true);
         int inMemory = wizard->exec();
-        //qDebug() << "MAIN: Wizard inMemory: " << QString::number(inMemory) << endl;
+          //qDebug() << "MAIN: Wizard inMemory: " << QString::number(inMemory) << endl;
+
 
         if (inMemory == 1)
         {
-           //qDebug() << "MAIN: Wizard accepted " << QString::number(inMemory) << " ... Will run in Memory " << endl;
-            MainWindow mw(klogDir, version);
-            mw.show();
-            return app.exec();
-        }
-        else if (inMemory == 2)
-        {
-            //qDebug() << "MAIN: Wizard accepted " << QString::number(inMemory) << " ... Will run in file " << endl;
-            MainWindow mw(klogDir, version);
+              //qDebug() << "MAIN: Wizard accepted " << QString::number(inMemory) << " ... Will run in Memory " << endl;
+            MainWindow mw(klogDir, version);     
+            mw.init();
+            splash.finish(&mw);
+            //mw.checkIfNewVersion();
+            //mw.recommendBackupIfNeeded();
             mw.show();
             return app.exec();
         }
+
         else
         {
-            //qDebug() << "MAIN: Wizard cancelled " << QString::number(inMemory) << " ... should close " << endl;
+               //qDebug() << "MAIN: Wizard cancelled " << QString::number(inMemory) << " ... should close " << endl;
 
             QMessageBox msgBox;
             msgBox.setText(QObject::tr("Install wizard was canceled before completing..."));
@@ -307,41 +310,39 @@ int main(int argc, char *argv[])
 
     else
     {
-         //qDebug() << "Main: Start of DB Activities" << endl;
+            //qDebug() << "Main: Start of DB Activities" << endl;
         DataBase *db = new DataBase(Q_FUNC_INFO, version, util.getKLogDBFile());
-        //qDebug() << "Main: After Start of DB Activities" << endl;
-        if (!db->createConnection())
+           //qDebug() << "Main: After Start of DB Activities" << endl;
+        if (!db->createConnection(Q_FUNC_INFO))
         {
-             //qDebug() << "Main: Conection not created" << endl;
+                //qDebug() << "Main: Conection not created" << endl;
             return -1; // Exits with an error; no DB has been created
         }
         else
         {
             db->updateIfNeeded(); // Check if we need to update the DB
-             //qDebug() << "Main: DB Updated" << endl;
+                //qDebug() << "Main: DB Updated" << endl;
         }
         db->~DataBase();
-         //qDebug() << "Main: End of DB Activities" << endl;
 
-         //qDebug() << "KLog Main-50" << (QTime::currentTime()).toString("HH:mm:ss") << endl;
-        QPixmap pixmap(":img/klog_512x512.png");
-         //qDebug() << "KLog Main-51" << (QTime::currentTime()).toString("HH:mm:ss") << endl;
-        QSplashScreen splash(pixmap);
-         //qDebug() << "KLog Main-52" << (QTime::currentTime()).toString("HH:mm:ss") << endl;
         splash.show();
-         //qDebug() << "KLog Main-100" << (QTime::currentTime()).toString("HH:mm:ss") << endl;
-        MainWindow mw(klogDir, version);
+          //qDebug() << "KLog Main-100" << (QTime::currentTime()).toString("HH:mm:ss") << endl;
+        MainWindow mw(klogDir, version);        
+        mw.init();
         splash.finish(&mw);
-         //qDebug() << "KLog Main-101" << (QTime::currentTime()).toString("HH:mm:ss") << endl;
-        mw.show();
-         //qDebug() << "KLog Main-101.5" << (QTime::currentTime()).toString("HH:mm:ss") << endl;
+        mw.checkIfNewVersion();
+        mw.recommendBackupIfNeeded();
 
-        //qDebug() << "KLog Main-102" << (QTime::currentTime()).toString("HH:mm:ss") << endl;
+            //qDebug() << "KLog Main-101" << (QTime::currentTime()).toString("HH:mm:ss") << endl;
+        mw.show();
+            //qDebug() << "KLog Main-101.5" << (QTime::currentTime()).toString("HH:mm:ss") << endl;
+
+           //qDebug() << "KLog Main-102" << (QTime::currentTime()).toString("HH:mm:ss") << endl;
 
         return app.exec();
-        //qDebug() << "KLog Main-103" << (QTime::currentTime()).toString("HH:mm:ss") << endl;
+           //qDebug() << "KLog Main-103" << (QTime::currentTime()).toString("HH:mm:ss") << endl;
     }
-    //qDebug() << "KLog Main-END: " << (QTime::currentTime()).toString("HH:mm:ss")  << endl;
+       //qDebug() << "KLog Main-END: " << (QTime::currentTime()).toString("HH:mm:ss")  << endl;
 
     //return app.exec();
 }
