@@ -9,20 +9,20 @@
  ***************************************************************************/
 
 /*****************************************************************************
- * This file is part of KLog.                                             *
+ * This file is part of KLog.                                                *
  *                                                                           *
- *    KLog is free software: you can redistribute it and/or modify        *
+ *    KLog is free software: you can redistribute it and/or modify           *
  *    it under the terms of the GNU General Public License as published by   *
  *    the Free Software Foundation, either version 3 of the License, or      *
  *    (at your option) any later version.                                    *
  *                                                                           *
- *    KLog is distributed in the hope that it will be useful,             *
+ *    KLog is distributed in the hope that it will be useful,                *
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.       *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
  *                                                                           *
  *****************************************************************************/
 
@@ -38,11 +38,13 @@
 #include "setupdialog.h"
 //#include "helpaboutdialog.h"
 #include "aboutdialog.h"
+//#include "dxccsummarydialog.h"
+#include "tipsdialog.h"
 #include "world.h"
 #include "filemanager.h"
-#include "contest.h"
-#include "contest_cqwwdxssb.h"
-#include "dataproxy.h"
+//#include "contest.h"
+//#include "contest_cqwwdxssb.h"
+#include "dataproxy_sqlite.h"
 #include "dataproxy_sqlite.h"
 #include "locator.h"
 #include "dxcluster.h"
@@ -53,10 +55,12 @@
 #include "mainwindowinputothers.h"
 #include "mainwindowinputeqsl.h"
 #include "mainwindowinputqsl.h"
+#include "mainqsoentrywidget.h"
 #include "elogclublog.h"
 #include "utilities.h"
 #include "downloadcty.h"
 #include "dxccstatuswidget.h"
+#include "awardswidget.h"
 #include "softwareupdate.h"
 #include "logmodel.h"
 #include "logwindow.h"
@@ -67,7 +71,12 @@
 #include "statisticswidget.h"
 #include "updatesatsdata.h"
 #include "hamlibclass.h"
-
+#include "pstrotatorsupport.h"
+#include "lotwutilities.h"
+#include "widgets/rotator.h"
+#include "widgets/adiflotwexportwidget.h"
+#include "widgets/showadifimportwidget.h"
+//#include "worldmapwidget.h"
 
 
 class QTimer;
@@ -85,7 +94,7 @@ class QMessageBox;
 class QTextEdit;
 class QProgressDialog;
 
-class QPoint;
+//class QPoint;
 
 class QGroupBox;
 class QTabWidget;
@@ -98,7 +107,7 @@ class QTableView;
 class QLabel;
 
 
-
+/*
 enum
 {
     Log_Id = 0,
@@ -109,6 +118,7 @@ enum
     Log_TimeId = 5
 };
 
+
 enum
 {
     DX = 0,
@@ -119,14 +129,19 @@ enum
     CQ_WPX_CW = 4,
     CQ_WPX_RTTY = 5
 };
-
+*/
+//enum ExportMode {ModeLotW, ModeADIF};
 
 class MainWindow : public  QMainWindow
 {
     Q_OBJECT
 
 public:
-    MainWindow(const QString _klogDir, const QString tversion);
+    MainWindow(const QString &_klogDir, const QString &tversion);
+    void checkIfNewVersion();
+    void recommendBackupIfNeeded();
+    void init();
+
      ~MainWindow();
 
 private slots:
@@ -134,18 +149,18 @@ private slots:
     void slotClearNoMorErrorShown();
     void slotQueryErrorManagement(QString functionFailed, QString errorCodeS, int errorCodeN, QString queryFailed);
     void slotQRZReturnPressed();
-    void slotQRZSpacePressed();
-    void slotQRZTextChanged();
-    void slotSRXTextChanged();
-    void slotSTXTextChanged();
+    //void slotQRZSpacePressed();
+    void slotQRZTextChanged(QString _qrz);
+    //void slotSRXTextChanged();
+    //void slotSTXTextChanged();
     void slotUpdateLocator(QString _loc);
     void slotLocatorTextChanged();
-    void slotMyLocatorTextChanged();
+    //void slotMyLocatorTextChanged();
     void slotFreqTXChanged();
     void slotFreqRXChanged();
 
     void slotSearchBoxTextChanged();
-    void slotCloseStats(bool _vis);
+    //void slotCloseStats(bool _vis);
     void slotSearchToolNeededQSLToSend();
     void slotToolSearchRequestedQSLToSend();
     void slotToolSearchNeededQSLPendingToReceive();
@@ -154,66 +169,88 @@ private slots:
     void slotToolLoTWMarkAllQueued();
     void slotToolLoTWMarkAllYesThisLog();
     void slotToolLoTWMarkAllYes();
+    void slotLoTWDownloadedFileProcess(const QString &_fn);
 
-    void slotModeComboBoxChanged();
-    void slotBandComboBoxChanged();
+    //void slotModeComboBoxChanged();
+    //void slotBandComboBoxChanged();
     //void slotIOTAComboBoxChanged();
-    void slotOperatingYearComboBoxChanged();
+    //void slotOperatingYearComboBoxChanged();
     void slotOKButtonClicked();
-    void slotSpotItButtonClicked();
+    //void slotSpotItButtonClicked();
     void slotClearButtonClicked();
+    void slotBandChanged (const QString &_b);
+    void slotModeChanged (const QString &_m);
     void slotRefreshDXCCWidget();
-    void slotUpdateTime();
+    //void slotUpdateTime();
     void slotLogWinShow();
     void slotLogRefresh();
-    void slotScoreWinShow();
+    //void slotScoreWinShow();
     void slotQSODelete(const int _id);
 
     void slotShowAwards();
-    void slotUpdateStatusBar(const QString statusm);
+    void slotUpdateStatusBar(const QString &statusm);
 
     void slotSetup(const int _page=0);
 
-    void slotrstTXTextChanged();
-    void slotrstRXTextChanged();
+    //void slotrstTXTextChanged();
+    //void slotrstRXTextChanged();
     void slotADIFExport();
-    void slotLoTWImport();
+    //void slotLoTWImport();
+    //void slotLoTWExport();
+
     void slotLoTWExport();
+    void slotLoTWDownload();
+    void slotADIFExportSelection(const QString &_st, const QDate &_startDate, const QDate &_endDate, const ExportMode _eM);
+    //void slotADIFExportPeriod(const QString &_st, const QDate &_startDate, const QDate &_endDate, const ExportMode _eM);
+
     void slotADIFExportAll();
     void slotADIFImport();
     void slotRQSLExport();
-    void slotCabrilloExport();
+    void slotReceiveQSOListToShowFromFile(QStringList _qs);
+    //void slotCabrilloExport();
     //void slotQSLViaTextChanged();
     void slotTimeOutInfoBars(); // Clears the infoLabels when the timeout emits the signal
 
-    void slotSetPropMode(const QString _p);
+    void slotSetPropMode(const QString &_p);
     void slotFillEmptyDXCCInTheLog();
     void slotUpdateCTYDAT();
     void slotUpdateSATSDAT();
     void slotShowStats();
-    void slotWorldReload();
+    //void slotShowDXCCSummary();
+    void slotWorldReload(const bool _b);
 
     void slotExitFromSlotDialog(const int exitID);
+    void exitQuestion();
 
     //void slotDownloadFinished(QNetworkReply *reply);
 
     void fillQSOData();
 
-    void newFile();
-    void openFile();
-    bool saveFile(const QString _fileName);
-    bool saveFileAs();
+    //void newFile();
+    //void openFile();
+    //bool saveFile(const QString &_fileName);
+    //bool saveFileAs();
     bool slotOpenKLogFolder();
 
     void slotFilePrint();
-    //void slotFileClose();
+    void slotFileClose();
 
     //void slotHelpHelpAction();
     void slotHelpAboutAction();
     void slotHelpCheckUpdatesAction();
     void slotAboutQt();
-       
-    void slotRecalculateAwardsButtonClicked();
+    void slotTipsAction();
+
+    // MainQSOEntryWidget
+    void slotShowInfoLabel(const QString _m);
+    //void slotClearForNextQSO();
+    // To support AwardsWidget
+    //void slotRecalculateAwardsButtonClicked();
+    void slotAwardsWidgetSetLog();
+    void slotAwardsWidgetSetYear();
+
+    // MyDataTab
+    void slotMyLocatorTextChanged(const QString _loc);
 
     // logpanel
     //void slotRighButtonFromLog( const QPoint& pos);
@@ -229,7 +266,7 @@ private slots:
 
     // CLUSTER
     //CLUBLOG
-    void slotElogClubLogShowMessage(const QString _s);
+    void slotElogClubLogShowMessage(const QString &_s);
     void slotElogClubLogProcessAnswer(const int _i, const int _qID);
     void slotElogClubLogDisable(const bool _b);
     //CLUBLOG
@@ -246,49 +283,72 @@ private slots:
 
     //HAMLIB
     void slotHamlibTXFreqChanged(const double _f);
-    void slotHamlibModeChanged(const QString _m);
+    void slotHamlibModeChanged(const QString &_m);
+    //void slotHamlibModeNotADIF();
+
+    // PST Rotator
+    void slotRotatorShow();
+    // WORLD MAP
+    //void slotWorldMapShow();
 
     //DXCCWIDGET
-    void slotShowQSOFromDXCCWidget(const int _q);
+    //void slotShowQSOFromDXCCWidget(const int _q);
     void slotShowQSOsFromDXCCWidget(QList<int> _qsos);
 
     //UDP Server (WXJT-x)
-    void slotWSJXstatusFromUDPServer(const int _type, const QString _dxcall, const double _freq, const QString _mode,
-                                 const QString _report, const QString _de_call, const QString _de_grid,
-                                 const QString _dx_grid, const QString _sub_mode);
+    void slotWSJXstatusFromUDPServer(const int _type, const QString &_dxcall, const double _freq, const QString &_mode,
+                                 const QString &_report, const QString &_de_call, const QString &_de_grid,
+                                 const QString &_dx_grid, const QString &_sub_mode);
 
 
 
-    void slotWSJTXloggedQSO(const int _type, const QString _dxcall, const double _freq, const QString _mode,
-                             const QString _dx_grid, const QString _time_off, const QString _report_sent, const QString _report_rec,
-                             const QString _tx_power, const QString _comments, const QString _name, const QString _time_on, const QString _de_call, const QString _de_grid);
+    void slotWSJTXloggedQSO(const int _type, const QString &_dxcall, const double _freq, const QString &_mode,
+                             const QString &_dx_grid, const QString &_time_off, const QString &_report_sent, const QString &_report_rec,
+                             const QString &_tx_power, const QString &_comments, const QString &_name, const QString &_time_on, const QString &_de_call, const QString &_de_grid);
 
+
+    //void slotTipsFindQSL2QSO();
+    //void slotTipsFillInDXCC();
+    //void slotsTipsFillQSO();
+
+    void slotCaptureDebugLogs(const QString &_func, const QString &_msg, const int _level=7);
 private:
+    //void setWidgetsOrder();
     bool maybeSave();
-    void updateBandComboBox(const QString _band);
+    void setCleaning(const bool _c);
+
+    void logEvent(const QString &_func, const QString &_msg, const int _level=7);
+    void setSeverity(const int _sev);
+    void updateBandComboBox(const QString &_band);
+    void fileExportLoTW(const QString &_st, const QDate &_startDate, const QDate &_endDate);
+    void fileExportADIF(const QString &_st, const QDate &_startDate, const QDate &_endDate);
+    bool callTQSL(const QString &_filename, const QString &_call);
+    void showNumberOfSavedQSO(const QString &_fn, const int _n);
+    //QString getCallToUseForLoTWExportUpload();
     UpdateSatsData *updateSatsData;
     //UPDATE CTY.DAT
     DownLoadCTY *downloadcty;
     HamLibClass *hamlib;
     bool hamlibActive;
-    //</UPDATE CTY.DAT>
+    bool hamlibChangingMode;
+    bool hamlibModeNotADIFSupported;
 
+    // PST Rotator
+    PSTRotatorSupport *pstRotator;
+    bool usePSTRotator;
+    RotatorWidget *rotatorWidget;
+    //</UPDATE CTY.DAT>
+    //WorldMapWidget *worldMapWidget;
     void createStatusBar();
-    void createUI();
-    void createUICQWW();
+    void createUI();    
     void createUIDX();
     void reconfigureDXMarathonUI(const bool _dxM);
     //void createDXClusterUI();
     void clearBandLabels();
 
     void createMenusCommon();
-    void createMenusCQWW();
     void createActionsCommon();
-    void createActionsCQWW();
-    void createActionsDX();
 
-    void createScorePanel();
-    void initialContestModeConfiguration();
 
 
     bool readCtyFile();
@@ -296,25 +356,26 @@ private:
     bool isQSLReceived(const int _qsoId);
     bool isQSLSent(const int _qsoId);
 
-    bool validCharactersInCall(const QString _qrz); // Looks for SQLi and no valid chars in the QRZ
+    //bool validCharactersInCall(const QString &_qrz); // Looks for SQLi and no valid chars in the QRZ
     QString readDataFromUI(); // Reads the QSO data from the UI and returns the SQL Query
     QString readDataFromUIDX();
     QString readDataFromUIDXModifying();
     void actionsJustAfterAddingOneQSO();
-    void clearForNextQSO();
+    //void clearForNextQSO();
     void clearUIDX(bool full=false); //full= false leaves some data to allow pileup or normal Dx in same band; full removes freqs and everything
 
     void setAwardDXCC(const int _qsoId, bool modifying); // Adds or modify the status of a DXCC entity
     // data << dxcc(id) << band(id) << mode(id) << confirmed(0/1) << qsoid(id) << modify(0/1);
 
-    void checkIfWorkedB4(const QString _qrz);
-    bool checkContest();    
+    //void checkIfWorkedB4(const QString &_qrz);
+    //bool checkContest();
     void showStatusOfDXCC(const QStringList _qs);
     void showDXMarathonNeeded(const int _dxcc, const int _cqz, const int _year, const int _log);
 
     bool createConnection();
     void createData();
-    bool processConfigLine(const QString _line);
+    void openSetup(const int _page=0);
+    bool processConfigLine(const QString &_line);
     void readConfigData();    
     void defineStationCallsign();
     QString selectStationCallsign();
@@ -324,26 +385,33 @@ private:
     void selectDefaultMode();
     void readActiveBands (const QStringList actives);
     void readActiveModes (const QStringList actives);
-    bool checkIfNewMode(const QString _mode);
-    void addNewValidMode(const QString _mode);
+    bool checkIfNewMode(const QString &_mode);
+    void addNewValidMode(const QString &_mode);
+    void setModeFromFreq();
 
     void qsoToEdit (const int _qso);
+    void setModifying(const bool _m);
 
-    void completeWithPreviousQSO(const QString _call);
+    void completeWithPreviousQSO(const QString &_call);
 
-    void showAwards();
-    void showDXMarathon(const int _year);
+    //void showAwards();
+    //void showDXMarathon(const int _year);
     void updateQSLRecAndSent();
     double checkFreqRanges(double _f);
-    void setRSTToMode(const QString _m);
+    void setRSTToMode(const QString &_m);
+
 
     // CLUSTER
-    void clusterSpotToLog(const QString _call, const QString _freq);
+    void clusterSpotToLog(const QString &_call, const QString &_freq);
     QStringList dxclusterServersList;
     QString dxclusterServerToConnect;
     int dxclusterServerPort;
     // CLUSTER
 
+    //LOTW
+    AdifLoTWExportWidget *adifLoTWExportWidget;
+    //LOTW
+    ShowAdifImportWidget *showAdifImportWidget;
 
     QWidget *mainWidget;
     //QWidget *dxClusterTabWidget;//, *searchTabWidget;
@@ -357,8 +425,11 @@ private:
     //HelpHelpDialog *helpHelpDialog;
     //HelpAboutDialog *helpAboutDialog;
     AboutDialog *aboutDialog;
+    TipsDialog *tipsDialog;
+    //DXCCSummaryDialog *dxccSummaryDialog;
 
-    QPushButton *addButton;
+
+    //QPushButton *addButton;
     //QLabel *distShortLabelN;
     //QLabel *distLongLabelN;
     StatisticsWidget *statsWidget;
@@ -369,8 +440,8 @@ private:
     //QTreeWidget *searchResultsTreeWidget;
     QLabel *logLabel;
 
-    QWidget *scoreWindow; //, dxWindow;
-    QTextEdit *scoreTextEdit;
+    //QWidget *scoreWindow; //, dxWindow;
+    //QTextEdit *scoreTextEdit;
 
     LogModel *logModel;
     LogWindow *logWindow;
@@ -383,10 +454,10 @@ private:
     QGroupBox *gridGroupBox, *qrzgroupBox;//, *searchgroupBox;
     QFrame *dxUpLeftInputFrame;//, *dxUpRightOutputFrame;
 
-    QLineEdit *qrzLineEdit, *nameLineEdit, *qthLineEdit, *locatorLineEdit;
-    QComboBox *bandComboBox, *modeComboBox;
-    QDateEdit *dateEdit;
-    QTimeEdit *timeEdit;
+    QLineEdit *nameLineEdit, *qthLineEdit, *locatorLineEdit;
+    //QComboBox *bandComboBox, *modeComboBox;
+    //QDateEdit *dateEdit;
+    //QTimeEdit *timeEdit;
     //QStatusBar *statusBar, *qsoStatusBar;
     QString statusBarMessage;
 
@@ -403,8 +474,8 @@ private:
     QMenu *helpMenu;
 
     QAction *klogFolderAct;
-    QAction *openAct;
-    QAction *saveAct;
+    //QAction *openAct;
+    //QAction *saveAct;
     QAction *exitAct;
     QAction *printLogAct;
     QAction *addAct;
@@ -414,6 +485,7 @@ private:
     QAction *setupAct;
     QAction *helpAct;
     QAction *aboutAct;
+    QAction *tipsAct;
     QAction *aboutQtAct;
     QAction *updateAct;
 
@@ -422,7 +494,7 @@ private:
     QAction *ADIFExport;
     QAction *ADIFExportAll;
     QAction *ADIFImport;
-    QAction *LoTWExport;
+    //QAction *LoTWExport;
     QAction *LoTWImport;
     QAction *ReqQSLExport;
     QAction *CabrilloExport;
@@ -436,10 +508,14 @@ private:
     QAction *lotwMarkSentQueuedAct;
     QAction *lotwMarkSentYesThisLogAct;
     QAction *lotwMarkSentYesAct;
+    QAction *lotwCallTQSL;
+    QAction *lotwUpdateFromLoTWAct;
 
     QAction *downloadCTYAct;
     QAction *downloadSATSAct;
     QAction *showStatsAct;
+    QAction *showRotatorAct;
+    //QAction *showDXCCSummaryAct;
 
     QAction *loggWinAct;
 /*
@@ -453,6 +529,8 @@ private:
     QAction *qslSentRequestedAct;
     QAction *qslRecRequestedAct;
 
+    //QAction *showWorldMapAct;
+
     //QAction *delQSOFromSearchAct;
     //QAction *qsoToEditFromSearchAct;
     //QAction *qslSentViaBureauFromSearchAct;
@@ -466,9 +544,9 @@ private:
 
     QLineEdit *rstTXLineEdit;
     QLineEdit *rstRXLineEdit;
-    QLineEdit *STXLineEdit;
-    QLineEdit *SRXLineEdit;
-    QPushButton *OKButton, *spotItButton, *clearButton;
+    //QLineEdit *STXLineEdit;
+    //QLineEdit *SRXLineEdit;
+    //QPushButton *OKButton, *spotItButton, *clearButton;
     QStringList bands;
     QStringList modes;
     QStringList entitiesList, propModeList;
@@ -486,16 +564,14 @@ private:
     //QLabel *gradLongLabel, *distLongLabel;
 
     //QComboBox *iotaContinentComboBox, *entityPrimDivComboBox, *entitySecDivComboBox, *entityNameComboBox, *propModeComboBox;
-    QComboBox *operatingYearsComboBox;
-    QLineEdit *operatorLineEdit, *stationCallSignLineEdit, *myLocatorLineEdit;//, *commentLineEdit, *iotaNumberLineEdit;
+
+    QLineEdit *operatorLineEdit, *stationCallSignLineEdit;//, *commentLineEdit, *iotaNumberLineEdit;
     QTextEdit *notesTextEdit;
     QDoubleSpinBox *rxPowerSpinBox,  *txFreqSpinBox, *rxFreqSpinBox; //*myPowerSpinBox,
     QLCDNumber *freqQLCDNumber;
-    QLCDNumber *dxccConfirmedQLCDNumber, *dxccWorkedQLCDNumber,
-                *wazConfirmedQLCDNumber, *wazWorkedQLCDNumber,
-                *localConfirmedQLCDNumber, *localWorkedQLCDNumber,
-                *qsoConfirmedQLCDNumber, *qsoWorkedQLCDNumber,
-                *dxMarathonQSOLCDNumber, *dxMarathonDXCCQLCDNumber, *dxMarathonCQQLCDNumber, *dxMarathonPointsQLCDNumber;
+
+    QString lotwTQSLpath;
+
     //eQSL
     //QComboBox *eqslSentComboBox, *eqslRecComboBox, *lotwSentComboBox, *lotwRecComboBox, *clublogComboBox;
     //QDateEdit *eqslSentQDateEdit, *eqslRecQDateEdit, *lotwSentQDateEdit, *lotwRecQDateEdit, *clublogQDateEdit;
@@ -509,10 +585,15 @@ private:
     //QLineEdit *searchBoxLineEdit;
     //QPushButton *searchBoxClearButton, *searchBoxExportButton, *searchBoxSelectAllButton, *searchBoxReSearchButton;
     //QRadioButton *searchAllRadioButton;
-    QPushButton *recalculateAwardsButton;
+    //QPushButton *recalculateAwardsButton;
     //bool searchSelectAllClicked, stationCallSignShownInSearch;
 
     bool checkNewVersions, reportInfo; // Selected in the Setup->Misc to check if new versions and report info back to KLog's servers
+    bool logEvents;                     // Should KLog log the events for debugging
+    bool debugFileOpen;                 //Is the debugFile open?
+    QFile *debugFile;
+    int logSeverity;    // Manages as syslog, the severity of the application debug log (7 means debug, 0 emergency)
+
     bool txFreqBeingChanged, rxFreqBeingChanged, updatingBands;            // When the freqs is being modified it is defined to true to prevent other automated to change.
     bool txFreqBeingAutoChanged, rxFreqBeingAutoChanged;        // This is defined to true when freq is being changed by the Sat tab to prevent a loop.
     bool qslingNeeded;
@@ -525,7 +606,9 @@ private:
     MainWindowInputOthers *othersTabWidget;
     MainWindowInputEQSL *eQSLTabWidget;
     MainWindowInputQSL *QSLTabWidget;
+    MainQSOEntryWidget *mainQSOEntryWidget;
 
+    AwardsWidget *awardsWidget;
     SearchWidget *searchWidget;
     InfoWidget *infoWidget;
 
@@ -546,7 +629,8 @@ private:
     // </UI>
     int infoTimeout; // timeout that temporary info will stay in the infobars
     QTimer *timer, *timerInfoBars;
-    QDateTime *dateTime;
+    QDateTime *dateTime, *dateTimeTemp;
+    bool yearChangedDuringModification;
     QString infoLabel1T, infoLabel2T;
 
     QString klogDir, ctyDatFile, defaultADIFLogFile, configFileName;
@@ -554,20 +638,21 @@ private:
     bool itIsANewversion;
 
 
-    QString currentQrz;
-    QString previousQrz;
+    //QString currentQrz;
+    //QString previousQrz;
 
     QString stx;
     QString srx;
     QPalette palRed, palBlack; // To paint Text in red or black(normal)
-    bool realTime, UTCTime, alwaysADIF, needToSave, useDefaultLogFileName, upAndRunning, qrzSmallModDontCalculate, imperialSystem, sendQSLWhenRec, manageDxMarathon, keepMyData, completeWithPrevious, completedWithPreviousQTH, completedWithPreviousLocator, completedWithPreviousName, completedWithPreviousIOTA, completedWithPreviousQSLVia;
+    bool  alwaysADIF, needToSave, useDefaultLogFileName, upAndRunning, qrzSmallModDontCalculate, imperialSystem, sendQSLWhenRec, manageDxMarathon, keepMyData, completeWithPrevious, completedWithPreviousQTH, completedWithPreviousLocator, completedWithPreviousName, completedWithPreviousIOTA, completedWithPreviousQSLVia;
+    // bool realTime, UTCTime;
     bool cleaning;
     bool manageMode; // If true, the DXCC and awards will take the mode into consideration to decide if needed or worked. False implies only band is taken into account
     // Station Setup
     bool configured, modify;
     bool needToEnd; // Just to control if the software needs to end.
-    bool qrzAutoChanging; //To stop executing the slotQRZTextChanged just because KLog uppercase a letter
-    QString mainQRZ, stationQRZ, operatorQRZ, myLocator, dxLocator;
+    //bool qrzAutoChanging; //To stop executing the slotQRZTextChanged just because KLog uppercase a letter
+    QString mainQRZ, stationQRZ, operatorQRZ, dxLocator;
     QString lastOperatorQRZ, lastStationQRZ, lastMyLocator;
     double myPower, lastPower;
 
@@ -578,6 +663,7 @@ private:
                     // them all at the same time.
     int modifyingQSO; // When modifying, the QSO is saved here.
     int selectedYear;
+    bool readingTheUI;  // While reading the data from UI after QSO intro or modificationthis is true
 
     // Station Setup
 
@@ -598,22 +684,21 @@ private:
     //</CLUBLOG>
 
     // Contest
-    int points, qsoPoints, multipliers, qsoMultiplier;
+    //int points, qsoPoints, multipliers, qsoMultiplier;
     QString contestMode;
-    Contest *contest;
+    //Contest *contest;
     // Contest
-    DataProxy *dataProxy;
+    DataProxy_SQLite *dataProxy;
 
     DataBase *db;
-    bool DBinMemory;
 
-    QTextDocument *doc;
 
     SoftwareUpdate *softUpdate;
     bool callingUpdate;
     
     bool UDPServerStart;
-
+    // LOTWUTILITIES
+    LoTWUtilities *lotwUtilities;
     //LOGVIEW
     //QString bandOld, modeOld;
     //LOGVIEW
