@@ -20,17 +20,17 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
  *                                                                           *
  *****************************************************************************/
 
 
 #include "mainwindowinputothers.h"
 
-MainWindowInputOthers::MainWindowInputOthers(DataProxy *dp, QWidget *parent) :
+MainWindowInputOthers::MainWindowInputOthers(DataProxy_SQLite *dp, QWidget *parent) :
     QWidget(parent)
 {
-     //qDebug() << "MainWindowInputOthers::MainWindowInputOthers" << endl;
+       //qDebug() << "MainWindowInputOthers::MainWindowInputOthers" << endl;
     entitiesList.clear();
     propModeList.clear();
 
@@ -51,14 +51,14 @@ MainWindowInputOthers::MainWindowInputOthers(DataProxy *dp, QWidget *parent) :
 
 
     createUI();
-     //qDebug() << "MainWindowInputOthers::MainWindowInputOthers - END" << endl;
+       //qDebug() << "MainWindowInputOthers::MainWindowInputOthers - END" << endl;
 }
 
 MainWindowInputOthers::~MainWindowInputOthers(){}
 
 void MainWindowInputOthers::createUI()
 {
-    //qDebug() << "MainWindowInputOthers::createUI" << endl;
+      //qDebug() << "MainWindowInputOthers::createUI" << endl;
 
     palRed.setColor(QPalette::Text, Qt::red);
     palBlack.setColor(QPalette::Text, Qt::black);
@@ -133,7 +133,7 @@ void MainWindowInputOthers::createUI()
 
 void MainWindowInputOthers::clear()
 {
-    //qDebug() << "MainWindowInputOthers::clear" << endl;
+      //qDebug() << "MainWindowInputOthers::clear" << endl;
     entityNameComboBox->setCurrentIndex(0);
     propModeComboBox->setCurrentIndex(0);
     iotaContinentComboBox->setCurrentIndex(0);
@@ -142,7 +142,7 @@ void MainWindowInputOthers::clear()
 
 void MainWindowInputOthers::setEntitiesList(const QStringList _qs)
 {
-    //qDebug() << "MainWindowInputOthers::setEntitiesList: " << QString::number(_qs.length()) << endl;
+      //qDebug() << "MainWindowInputOthers::setEntitiesList: " << QString::number(_qs.length()) << endl;
     entitiesList.clear();
     entitiesList << _qs;
     if (entitiesList.size()>1)
@@ -155,7 +155,7 @@ void MainWindowInputOthers::setEntitiesList(const QStringList _qs)
 
 void MainWindowInputOthers::setEntity(const int _ent)
 {// Select the appropriate entity in the ComboBox
-     //qDebug() << "MainWindowInputOthers::setEntity: " << QString::number(_ent) << endl;
+       //qDebug() << "MainWindowInputOthers::setEntity: " << QString::number(_ent) << endl;
     if (_ent<=0)
     {
         entityNameComboBox->setCurrentIndex(0);
@@ -174,11 +174,11 @@ void MainWindowInputOthers::setEntity(const int _ent)
     pref = dataProxy->getEntityNameFromId(_ent);
 
     //int indexC = entityNameComboBox->findText(pref, Qt::MatchContains);
-     //qDebug() << "MainWindow::selectCorrectEntity: aux to the findText: " << aux << endl;
+       //qDebug() << "MainWindow::selectCorrectEntity: aux to the findText: " << aux << endl;
     //int indexC = entityNameComboBox->findText("(" + aux + ")", Qt::MatchContains);
     int indexC = entityNameComboBox->findText("(" + aux + ")", Qt::MatchEndsWith);
 
-     //qDebug() << "MainWindow::selectCorrectEntity: " << pref << "/" << QString::number(indexC) << endl;
+       //qDebug() << "MainWindow::selectCorrectEntity: " << pref << "/" << QString::number(indexC) << endl;
     entityNameComboBox->setCurrentIndex(indexC);
     setIOTAContinentFromEntity(_ent);
 
@@ -186,14 +186,14 @@ void MainWindowInputOthers::setEntity(const int _ent)
 
 QString MainWindowInputOthers::getEntityPrefix()
 {
-    //qDebug() << "MainWindowInputOthers::getEntityName" << endl;
+    //qDebug() << "MainWindowInputOthers::getEntityPrefix: " << (entityNameComboBox->currentText()).split('-').at(0) << endl;
     return (entityNameComboBox->currentText()).split('-').at(0);
     //return world->getQRZARRLId(pref);
 }
 
 void MainWindowInputOthers::setPropMode(const QString _qs)
 {
-    //qDebug() << "MainWindowInputOthers::setPropMode: " << _qs << endl;
+      //qDebug() << "MainWindowInputOthers::setPropMode: " << _qs << endl;
     if(( propModeComboBox->findText(_qs+" -", Qt::MatchContains))>0)
     {
         propModeComboBox->setCurrentIndex( propModeComboBox->findText(_qs+" -", Qt::MatchContains));
@@ -207,10 +207,12 @@ void MainWindowInputOthers::setPropMode(const QString _qs)
 QString MainWindowInputOthers::getPropModeFromComboBox()
 {
     QString _pm = QString();
-   //qDebug() << "MainWindow::getPropModeFromComboBox:" << propModeComboBox->currentText() << endl;
+      //qDebug() << "MainWindow::getPropModeFromComboBox:" << propModeComboBox->currentText() << endl;
     _pm = (((propModeComboBox->currentText()).split('-')).at(1)).simplified();
-   //qDebug() << "MainWindow::getPropModeFromComboBox: " << _pm << endl;
-    if (_pm == "Not")
+    QString _n = (((propModeComboBox->currentText()).split('-')).at(0)).simplified();
+      //qDebug() << "MainWindow::getPropModeFromComboBox: " << _pm << endl;
+
+    if (_n == "00")
     {
         return QString();
     }
@@ -241,7 +243,7 @@ void MainWindowInputOthers::setIOTA(const QString _qs, const bool _black)
 {//TODO: Seems to be better to send the color info like in: (it is much more flexible as I can send any color!)
 
     //void MainWindowInputQSL::setQSLVia(const QString _qs, QColor qColor)
-    //qDebug() << "MainWindow::setIOTA: " << _qs << endl;
+      //qDebug() << "MainWindow::setIOTA: " << _qs << endl;
     if ( (checkIfValidIOTA(_qs)).length() !=6 )
     {
         return;
@@ -249,7 +251,7 @@ void MainWindowInputOthers::setIOTA(const QString _qs, const bool _black)
     else
     {
         QStringList values = _qs.split("-", QString::SkipEmptyParts);
-        //qDebug() << "MainWindowInputOthers::setIOTA: IOTA " << _qs << endl;
+          //qDebug() << "MainWindowInputOthers::setIOTA: IOTA " << _qs << endl;
         iotaContinentComboBox->setCurrentIndex( iotaContinentComboBox->findText(values.at(0) ) );
         iotaNumberLineEdit->setText(values.at(1));
     }
@@ -271,22 +273,22 @@ QString MainWindowInputOthers::getIOTA()
 
 void MainWindowInputOthers::setIOTAContinentFromEntity(const int _n)
 {
-    //qDebug() << "MainWindow::setIOTAContinentFromEntity:" << QString::number(_n) << endl;
+      //qDebug() << "MainWindow::setIOTAContinentFromEntity:" << QString::number(_n) << endl;
     setIOTAContinent(dataProxy->getContinentShortNameFromEntity(_n)) ;
 }
 
 void MainWindowInputOthers::setIOTAContinent(const QString _qs)
 {
-     //qDebug() << "MainWindowInputOthers::setIOTAContinent: " << _qs << endl;
-     //qDebug() << "MainWindowInputOthers::setIOTAContinent: setting to index(a): " << QString::number(iotaContinentComboBox->findText(_qs, Qt::MatchContains)) << endl;
+       //qDebug() << "MainWindowInputOthers::setIOTAContinent: " << _qs << endl;
+       //qDebug() << "MainWindowInputOthers::setIOTAContinent: setting to index(a): " << QString::number(iotaContinentComboBox->findText(_qs, Qt::MatchContains)) << endl;
     if(( iotaContinentComboBox->findText(_qs, Qt::MatchContains))>0)
     {
-        //qDebug() << "MainWindowInputOthers::setIOTAContinent: setting to index: " << QString::number(iotaContinentComboBox->findText(_qs, Qt::MatchContains)) << endl;
+          //qDebug() << "MainWindowInputOthers::setIOTAContinent: setting to index: " << QString::number(iotaContinentComboBox->findText(_qs, Qt::MatchContains)) << endl;
         iotaContinentComboBox->setCurrentIndex( iotaContinentComboBox->findText(_qs, Qt::MatchContains));
     }
     else
     {
-         //qDebug() << "MainWindowInputOthers::setIOTAContinent: setting to index: 00" << endl;
+           //qDebug() << "MainWindowInputOthers::setIOTAContinent: setting to index: 00" << endl;
         iotaContinentComboBox->setCurrentIndex(0);
     }
 }
@@ -306,7 +308,7 @@ QString MainWindowInputOthers::checkIfValidIOTA(const QString _tiota)
 Returns a valid format IOTA if possible and "" in other cases.
 
 ************************************/
-    //qDebug() << "MainWindowInputOthers::checkIfValidIOTA: " << _tiota << endl;
+      //qDebug() << "MainWindowInputOthers::checkIfValidIOTA: " << _tiota << endl;
     //bool _valid = false;
     QString _continent;
     QString _number;
@@ -322,8 +324,8 @@ Returns a valid format IOTA if possible and "" in other cases.
         return "";
     }
 
-    //qDebug() << "MainWindowInputOthers::checkIfValidIOTA (cont) " << _continent << endl;
-    //qDebug() << "MainWindowInputOthers::checkIfValidIOTA (numb): " << _number << endl;
+      //qDebug() << "MainWindowInputOthers::checkIfValidIOTA (cont) " << _continent << endl;
+      //qDebug() << "MainWindowInputOthers::checkIfValidIOTA (numb): " << _number << endl;
 
     // Check if continent is valid
 
