@@ -20,7 +20,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
  *                                                                           *
  *****************************************************************************/
 
@@ -29,12 +29,13 @@
 MainWindowMyDataTab::MainWindowMyDataTab(QWidget *parent) :
     QWidget(parent)
 {
-     //qDebug() << "MainWindowMyDataTab::MainWindowMyDataTab"   << endl;
+       //qDebug() << "MainWindowMyDataTab::MainWindowMyDataTab"   << endl;
     myPowerSpinBox = new QDoubleSpinBox;
     operatorLineEdit = new QLineEdit;
     stationCallSignLineEdit = new QLineEdit;
     myLocatorLineEdit = new QLineEdit;
     keepThisDataForNextQSORadiobutton = new QRadioButton;
+    locator = new Locator();
 
     lastOperatorQRZ = QString();    // Last QRZ used by the user, will remain if the button is checked and removed if not
     lastStationQRZ = QString();     // Last QRZ used by the user, will remain if the button is checked and removed if not
@@ -43,12 +44,13 @@ MainWindowMyDataTab::MainWindowMyDataTab(QWidget *parent) :
     stationQRZ = QString();         // Defined in the configuration by the user, will be used if the user configured so in the setup
     operatorQRZ = QString();        // Defined in the configuration by the user, will be used if the user configured so in the setup
     myLocator = QString();          // Defined in the configuration by the user, will be used if the user configured so in the setup
+    util = new Utilities;
 
     createUI();
 
     myPower = 0;
     lastPower = 0;
-     //qDebug() << "MainWindowMyDataTab::MainWindowMyDataTab - END"   << endl;
+       //qDebug() << "MainWindowMyDataTab::MainWindowMyDataTab - END"   << endl;
 
 }
 
@@ -56,9 +58,12 @@ MainWindowMyDataTab::~MainWindowMyDataTab(){}
 
 void MainWindowMyDataTab::createUI()
 {
+    palRed.setColor(QPalette::Text, Qt::red);
+    palBlack.setColor(QPalette::Text, Qt::black);
+
     myPowerSpinBox->setDecimals(2);
     myPowerSpinBox->setMaximum(9999);
-    myPowerSpinBox->setSuffix(" " + tr("Watt"));
+    myPowerSpinBox->setSuffix(" " + tr("Watts"));
 
     QLabel *keepLabel = new QLabel();
     keepLabel->setText(tr("Keep this data"));
@@ -102,7 +107,12 @@ void MainWindowMyDataTab::createUI()
     //myDataInputTabWidget->setLayout(myDataInputTabWidgetLayout);
    // i = dxUpLeftTab->addTab(myDataInputTabWidget, tr("My Data"));
     //connect(stationCallSignLineEdit, SIGNAL(returnPressed()), this, SLOT(slotQRZReturnPressed() ) );
-
+    connect(myLocatorLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotMyLocatorTextChanged() ) );
+    connect(myLocatorLineEdit, SIGNAL(returnPressed()), this, SLOT(slotReturnPressed() ) );
+    connect(operatorLineEdit, SIGNAL(returnPressed()), this, SLOT(slotReturnPressed() ) );
+    connect(operatorLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotOperatorTextChanged()) );
+    connect(stationCallSignLineEdit, SIGNAL(returnPressed()), this, SLOT(slotReturnPressed() ) );    
+    connect(stationCallSignLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotStationCallSignTextChanged() ) );
 }
 
 void MainWindowMyDataTab::clear(const bool _keepMyData)
@@ -110,11 +120,11 @@ void MainWindowMyDataTab::clear(const bool _keepMyData)
     // _keepMyData comes from the setup
     if (_keepMyData)
     {
-        //qDebug() << "MainWindowMyDataTab::clear:  TRUE"  << endl;
+          //qDebug() << "MainWindowMyDataTab::clear:  TRUE"  << endl;
     }
     else
     {
-        //qDebug() << "MainWindowMyDataTab::clear:  FALSE"  << endl;
+          //qDebug() << "MainWindowMyDataTab::clear:  FALSE"  << endl;
     }
 
     if (keepThisDataForNextQSORadiobutton->isChecked())
@@ -122,6 +132,7 @@ void MainWindowMyDataTab::clear(const bool _keepMyData)
         myPowerSpinBox->setValue(lastPower);
         operatorLineEdit->setText(lastOperatorQRZ.toUpper());
         stationCallSignLineEdit->setText(lastStationQRZ.toUpper());
+        //qDebug() << "MainWindowMyDataTab::clear-1: setMyLocator: " << myLocator  << endl;
         myLocatorLineEdit->setText(lastMyLocator);
     }
     else
@@ -131,6 +142,7 @@ void MainWindowMyDataTab::clear(const bool _keepMyData)
             myPowerSpinBox->setValue(myPower);
             operatorLineEdit->setText(operatorQRZ.toUpper());
             stationCallSignLineEdit->setText(stationQRZ.toUpper());
+            //qDebug() << "MainWindowMyDataTab::clear-2: setMyLocator: " << myLocator  << endl;
             myLocatorLineEdit->setText(myLocator);
         }
         else
@@ -145,14 +157,49 @@ void MainWindowMyDataTab::clear(const bool _keepMyData)
 
 void MainWindowMyDataTab::show()
 {
-
-     //qDebug() << "MainWindowMyDataTab::show: " << QString::number(myPower) << "/" << operatorQRZ << "/" << stationQRZ << "/" << myLocator << endl;
+       //qDebug() << "MainWindowMyDataTab::show: " << QString::number(myPower) << "/" << operatorQRZ << "/" << stationQRZ << "/" << myLocator << endl;
     myPowerSpinBox->setValue(myPower);
     operatorLineEdit->setText(operatorQRZ);
     stationCallSignLineEdit->setText(stationQRZ);
+    //qDebug() << "MainWindowMyDataTab::show: setMyLocator: " << myLocator  << endl;
     myLocatorLineEdit->setText(myLocator);
 }
 
+void MainWindowMyDataTab::slotMyLocatorTextChanged()
+{
+          //qDebug() << "MainWindowMyDataTab::slotMyLocatorTextChanged: " << myLocatorLineEdit->text() << endl;
+    //logEvent(Q_FUNC_INFO, "Start", logSeverity);
+    int cursorP = myLocatorLineEdit->cursorPosition();
+    myLocatorLineEdit->setText(myLocatorLineEdit->text().toUpper());
+    //qDebug() << "MainWindowMyDataTab::clear: setMyLocator: " << myLocatorLineEdit->text()  << endl;
+    if ( locator->isValidLocator((myLocatorLineEdit->text()).toUpper()) )
+    {
+        myLocator = (myLocatorLineEdit->text()).toUpper();
+        myLocatorLineEdit->setPalette(palBlack);
+        myLocatorLineEdit->setToolTip(tr("My QTH locator."));
+        myLocatorLineEdit->setCursorPosition(cursorP);
+        emit myLocChangedSignal(myLocator);
+
+        //dxccStatusWidget->setMyLocator(myLocator);
+              //qDebug() << "MainWindowMyDataTab::slotMyLocatorTextChanged: My LOCATOR CHANGED TO: " << myLocator << endl;
+        //slotLocatorTextChanged();
+    }
+    else
+    {
+        //logEvent(Q_FUNC_INFO, "END-2", logSeverity);
+        myLocatorLineEdit->setPalette(palRed);
+        myLocatorLineEdit->setToolTip(tr("My QTH locator. Format should be Maidenhead like IN70AA up to 10 characters."));
+        myLocatorLineEdit->setCursorPosition(cursorP);
+        return;
+    }
+    //logEvent(Q_FUNC_INFO, "END", logSeverity);
+}
+
+void MainWindowMyDataTab::slotReturnPressed()
+{
+    emit returnPressed();
+}
+
 void MainWindowMyDataTab::setSetupMyPower(const double _power)
 {
     myPower = _power;
@@ -175,7 +222,7 @@ void MainWindowMyDataTab::setSetupMyLocator(const QString _op)
 
 void MainWindowMyDataTab::setMyPower(const double _power)
 {
-    //qDebug() << "MainWindowMyDataTab::setMyPower: " << QString::number(_power) << endl;
+      //qDebug() << "MainWindowMyDataTab::setMyPower: " << QString::number(_power) << endl;
     myPowerSpinBox->setValue(_power);
 }
 
@@ -221,6 +268,7 @@ QString MainWindowMyDataTab::getStationQRZ()
 
 void MainWindowMyDataTab::setMyLocator(const QString _op)
 {
+    //qDebug() << "MainWindowMyDataTab::setMyLocator: " << _op << endl;
     myLocatorLineEdit->setText(_op);
 }
 
@@ -269,3 +317,35 @@ void MainWindowMyDataTab::setData(const double _power, const QString _stationQRZ
         myLocator = QString();
     }
 }
+
+void MainWindowMyDataTab::slotOperatorTextChanged()
+{
+    int cursorP = operatorLineEdit->cursorPosition();
+    operatorLineEdit->setText(operatorLineEdit->text().toUpper());
+    if (util->isValidCall(operatorLineEdit->text()))
+    {
+        operatorLineEdit->setPalette(palBlack);
+        operatorQRZ = (operatorLineEdit->text()).toUpper();
+    }
+    else
+    {
+        operatorLineEdit->setPalette(palRed);
+    }
+    operatorLineEdit->setCursorPosition(cursorP);
+}
+
+void MainWindowMyDataTab::slotStationCallSignTextChanged()
+{
+    int cursorP = stationCallSignLineEdit->cursorPosition();
+    stationCallSignLineEdit->setText(stationCallSignLineEdit->text().toUpper());
+    if (util->isValidCall(stationCallSignLineEdit->text()))
+    {
+        stationCallSignLineEdit->setPalette(palBlack);
+        stationQRZ = (stationCallSignLineEdit->text()).toUpper();
+    }
+    else
+    {
+        stationCallSignLineEdit->setPalette(palRed);
+    }
+    stationCallSignLineEdit->setCursorPosition(cursorP);
+}
