@@ -22,7 +22,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
  *                                                                           *
  *****************************************************************************/
 //
@@ -31,14 +31,14 @@
 
 #include <QWidget>
 #include <QtWidgets>
-#include "dataproxy.h"
+#include "dataproxy_sqlite.h"
 #include "locator.h"
 
 class MainWindowSatTab : public QWidget
 {
     Q_OBJECT
 public:
-    explicit MainWindowSatTab(DataProxy *dp, QWidget *parent = 0);
+    explicit MainWindowSatTab(DataProxy_SQLite *dp, QWidget *parent = 0);
     ~MainWindowSatTab();
 
     QString getSatName();
@@ -46,13 +46,15 @@ public:
     void setOtherSatName(const QString _t);
     QString getOtherSatName();
     QString getSatMode();
+    double getRXFreq();
     void setSatMode(const QString _t);
 
+
     bool getRepeatThis();
     void setRepeatThis(const bool _t);
 
     void addBands(QStringList _bands);
-    void setDefaultBands(); //Defines the default bands for SAT communications: 10m/2m/70cm/23CM only if they exist on the selected bands
+    void setDefaultBands(); //Defines the default bands for SAT communications: 10m/2m/70cm/23CM only if they exist in the selected bands
 
 
     void setUpLinkFreq(const double _t);
@@ -60,6 +62,7 @@ public:
 
     void setLocator(const QString _t);
     void refreshData();
+    void setModifying (const bool _m);
 
     void clear();
 
@@ -73,6 +76,7 @@ signals:
     void satTXFreqNeeded(const double _p);
     void satRXFreqNeeded(const double _p);
     void dxLocatorChanged(const QString _p);
+    void returnPressed();
 
 private slots:
     void slotSatNameTextChanged();
@@ -83,6 +87,7 @@ private slots:
     void slotSatBandTXComboBoxChanged();
     void slotSatFreqRXChanged();
     void slotSatFreqTXChanged();
+    void slotReturnPressed();
 
 private:
     void createUI();
@@ -93,6 +98,7 @@ private:
     void addNewBand(const QString _p);
     void setUpLink(const QString _t);
 
+
     QLineEdit *satNameLineEdit;
     QLineEdit *satModeLineEdit;
     QLineEdit *satDXLocatorLineEdit;
@@ -109,8 +115,9 @@ private:
     QPalette palRed, palBlack; // To paint Text in red or black(normal)
 
     QDoubleSpinBox *txFreqSpinBox, *rxFreqSpinBox;
-    DataProxy *dataProxy;
+    DataProxy_SQLite *dataProxy;
     Locator *locator;
+    bool modifying;
 };
 
 #endif // MAINWINDOWSATTAB_H
