@@ -22,7 +22,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
  *                                                                           *
  *****************************************************************************/
 //
@@ -30,7 +30,7 @@
 //
 #include <QWidget>
 #include <QtWidgets>
-#include "dataproxy.h"
+#include "dataproxy_sqlite.h"
 #include "awards.h"
 #include "world.h"
 #include "utilities.h"
@@ -40,7 +40,7 @@ class SearchWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit SearchWidget(DataProxy *dp, QWidget *parent = 0);
+    explicit SearchWidget(DataProxy_SQLite *dp, QWidget *parent = 0);
     ~SearchWidget();
     void setCurrentLog(const int _log);
     void setColors (const QString _newOne, const QString _needed, const QString _worked, const QString _confirmed, const QString _default);
@@ -49,6 +49,7 @@ public:
     void clear();
     void showQSO(const int _q);
     void showQSOs(QList<int> qsoIdList);
+    void setStationCallsign(const QString &_st);
 
     void searchToolNeededQSLToSend();
 
@@ -89,6 +90,8 @@ private slots:
     void slotQSOToEditFromSearch();
     void qslRecViaBureauMarkReq(const int _qsoId);
     void qslRecViaDirectMarkReq(const int _qsoId);
+    void slotStationCallsignChanged();
+    void slotRadioButtonToggled();
 
 
 signals:
@@ -103,6 +106,8 @@ signals:
 
 private:
     void createUI();
+    void selectStationCallSign();
+    void fillStationCallsignComboBox();
     // The following  function is adding a line to the search list
     void addQSOToSearchList(const QString _call, const QString _dateTime, const QString _band, const QString _mode, const QString _qslrx, const QString _qsltx, const QString _stationcallsign, const QString _id, const QColor _color);
     bool fillTheList(const QString _query);
@@ -113,12 +118,14 @@ private:
     QPushButton *searchBoxClearButton, *searchBoxExportButton, *searchBoxSelectAllButton, *searchBoxReSearchButton;
     QRadioButton *searchAllRadioButton;
     QTreeWidget *searchResultsTreeWidget;
+    QComboBox *stationCallsignComboBox;
 
     bool qslingNeeded;
     bool searchSelectAllClicked, stationCallSignShownInSearch;
     int currentLog;
+    QString mainStationCallsign;
 
-    DataProxy *dataProxy;
+    DataProxy_SQLite *dataProxy;
     Awards *awards;
     World *world;
     Utilities *util;
@@ -139,6 +146,8 @@ private:
     QAction *qslSentRequestedAct;
     QAction *qslRecRequestedAct;
 
+
+
 };
 
 #endif // SEARCHWIDGET_H
