@@ -22,26 +22,26 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.       *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.       *
  *                                                                           *
  *****************************************************************************/
 
 #include <QDialog>
 
-#include "setuppageuserdata.h"
-#include "setuppagebandmode.h"
-#include "setuppagemisc.h"
-#include "setuppagedxcluster.h"
-#include "setuppagecolors.h"
-#include "setuppagelogs.h"
-#include "setuppageworldeditor.h"
-#include "setuppageclublog.h"
-#include "setuppageudp.h"
-#include "setuppagesats.h"
-#include "setuppagehamlib.h"
+#include "setuppages/setuppageuserdata.h"
+#include "setuppages/setuppagebandmode.h"
+#include "setuppages/setuppagemisc.h"
+#include "setuppages/setuppagedxcluster.h"
+#include "setuppages/setuppagecolors.h"
+#include "setuppages/setuppagelogs.h"
+#include "setuppages/setuppageworldeditor.h"
+#include "setuppages/setuppageclublog.h"
+#include "setuppages/setuppagelotw.h"
+#include "setuppages/setuppageudp.h"
+#include "setuppages/setuppagesats.h"
+#include "setuppages/setuppagehamlib.h"
+#include "setuppages/setuppageinterfaceswindows.h"
 #include "utilities.h"
-
-
 #include "locator.h"
 
 
@@ -54,19 +54,21 @@ class SetupDialog : public QDialog
     Q_OBJECT
 
 public:
-    SetupDialog(DataProxy *dp, const bool _firstTime=true);
-    SetupDialog(DataProxy *dp, const QString _configFile, const QString _softwareVersion, const int _page=0, const bool _firstTime = true);
+    SetupDialog(DataProxy_SQLite *dp, const bool _firstTime=true);
+    SetupDialog(DataProxy_SQLite *dp, const QString &_configFile, const QString &_softwareVersion, const int _page=0, const bool _firstTime = true);
     ~SetupDialog();
 
-    void setData(const QString _configFile, const QString _softwareVersion, const int _page, const bool _firstTime=true);
+    void setData(const QString &_configFile, const QString &_softwareVersion, const int _page, const bool _firstTime=true);
     void setClubLogActive(const bool _b);
     void checkIfNewBandOrMode();
+    void setSeverity(const int _sev);
 
 public slots:
 
 signals:
     void exitSignal(const int status); // 1 = OK, -1 = NOK, 2 = Cancel clicked
     void queryError(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery); // To alert about any failed query execution
+    void debugLog (QString _func, QString _msg, int _level);
     //void newLogRequested(const bool _s); // true show new log
 
 private slots:
@@ -75,29 +77,30 @@ private slots:
     void slotOkButtonClicked();
     void slotCancelButtonClicked();
     void slotAnalyzeNewLogData(const QStringList _qs);  // We receive the station callsign and operators from the logs tab
-    void slotSetStationCallSign(const QString _p);      // We receive te station callsign from the userData tab to fill the new log
-    void slotSetOperators(const QString _p);            // We receive te station operators from the userData tab to fill the new log
+    void slotSetStationCallSign(const QString &_p);      // We receive te station callsign from the userData tab to fill the new log
+    void slotSetOperators(const QString &_p);            // We receive te station operators from the userData tab to fill the new log
     void slotQueryErrorManagement(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery);
+    void slotFocusOK();
 
 private:
-
-    void setConfigFile(const QString _configFile);
-    void setSoftVersion(const QString _softwareVersion);
+    void showEvent(QShowEvent *event);
+    void setConfigFile(const QString &_configFile);
+    void setSoftVersion(const QString &_softwareVersion);
     void setConfigured(const bool _configured);
     void setPage(const int _page);
     void connectActions();
 
     void createIcons();
-    bool processConfigLine(const QString _line);
+    bool processConfigLine(const QString &_line);
 
     void setDefaults();
 
-    void readActiveBands (const QString actives);
-    void readActiveModes (const QString actives);
-    bool isValidBand (const QString b);
-    bool isValidMode (const QString b);
+    void readActiveBands (const QString &actives);
+    void readActiveModes (const QString &actives);
+    bool isValidBand (const QString &b);
+    bool isValidMode (const QString &b);
 
-    QString checkAndFixASCIIinADIF(const QString _data);
+    QString checkAndFixASCIIinADIF(const QString &_data);
     bool haveAtleastOneLog();
 
     bool firstTime; // To know if we are calling it from the Start wizard or not
@@ -105,6 +108,7 @@ private:
     QString dxClusterServerToUse;
     QStringList dxClusterServers;
 
+    QPushButton *okButton;
     QTabWidget *tabWidget;
     int logsPageTabN;
 
@@ -119,9 +123,11 @@ private:
     SetupPageLogs *logsPage;
     SetupPageWorldEditor *worldEditorPage;
     SetupPageClubLog *clubLogPage;
+    SetupPageLoTW *lotwPage;
     SetupPageUDP *UDPPage;
     SetupPageSats *satsPage;
     SetupPageHamLib *hamlibPage;
+    SetupPageInterfacesWindows *interfacesWindowsPage;
 
     int pageRequested; // The page on the Dialog that is requested to be shown when you call it
     //QString klogDir;
@@ -129,11 +135,12 @@ private:
 
     QStringList bands, modes;
     Locator *locator;
-    DataProxy *dataProxy;
+    DataProxy_SQLite *dataProxy;
 
     Utilities *util;
 
     int constrid; // Just an id for the constructor to check who is being executed at one specific time
+    int logSeverity;    // Manages as syslog, the severity of the application debug log
 };
 
 
