@@ -11,7 +11,7 @@ class UDPServer : public QObject
     Q_OBJECT
 
 public:
-    explicit UDPServer(QObject *parent = 0);
+    explicit UDPServer(QObject *parent = nullptr);
     bool start();
     bool stop();
     bool isStarted();
