@@ -22,7 +22,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
  *                                                                           *
  *****************************************************************************/
 /*
@@ -37,28 +37,34 @@
 #include "locator.h"
 #include <QtDebug>
 
+enum ExportMode {ModeLotW, ModeADIF};
+
 class Utilities
 {
 public:
     Utilities();
     ~Utilities();
     int getProgresStepForDialog(int totalSteps);
-    bool trueOrFalse(const QString _s); // reads a String and return true if s.upper()== TRUE :-)
-    QString checkAndFixASCIIinADIF(const QString _data);
-    QString getAgent(const QString _klogversion);
+    bool trueOrFalse(const QString &_s); // reads a String and return true if s.upper()== TRUE :-)
+    QString checkAndFixASCIIinADIF(const QString &_data);
+    QString getAgent(const QString &_klogversion);
+    //QOperatingSystemVersion getOS();
     //Devel or debug functions - Not adding any feature to the user
-    void printQString(const QStringList _qs);
+    void printQString(const QStringList &_qs);
     QString getKLogDBFile();
 
-    //QString getKLogDatabaseFile(const QString _file);
+    //QString getKLogDatabaseFile(const QString &_file);
     bool isDBFileExisting();
-    bool isDBFileExisting(const QString _file);
-
+    bool isDBFileExisting(const QString &_file);
+    QString getTQSLsFileName();
+    QString getTQSLsPath();   // Depending on the OS where are usually installed the executables
     QString getHomeDir();
     QString getCfgFile();
     QString getCTYFile();
+    QString getDebugLogFile();
+    QString getSaveSpotsLogFile();
 
-    void setVersion(const QString _v);
+    void setVersion(const QString &_v);
     QString getVersion();
     double getVersionDouble();
 
@@ -67,23 +73,26 @@ public:
 
     // Validations
     bool isValidDate(const QDate _d);
-    bool isValidDateTime(const QString _d);
-    bool isValidCall(const QString _c);
-    bool isValidTime(const QString _t);
+    bool isValidDateTime(const QString &_d);
+    bool isValidCall(const QString &_c);
+    bool isValidTime(const QString &_t);
     bool isValidBandId(const int _b);
     bool isValidModeId(const int _m);
-    bool isValidFreq(const QString _b);
-    bool isValidGrid(const QString _b);
-    bool isValidRST(const QString _b);
-    bool isValidPower(const QString _b);
-    bool isValidComment(const QString _b);
-    bool isValidName(const QString _b);
-    bool isValidADIFField(const QString _b);
-    QStringList getValidADIFFieldAndData(const QString _b);
+    bool isValidFreq(const QString &_b);
+    bool isValidGrid(const QString &_b);
+    bool isValidRST(const QString &_b);
+    bool isValidPower(const QString &_b);
+    bool isValidComment(const QString &_b);
+    bool isValidName(const QString &_b);
+    bool isValidADIFField(const QString &_b);
+
+
+    QStringList getValidADIFFieldAndData(const QString &_b);
+    QString getAValidCall (const QString &_wrongCall);
 
 
 private:
-    bool processConfigLine(const QString _line);
+    bool processConfigLine(const QString &_line);
     QString getKLogDefaultDatabaseFile();
     QString dbPath;
     QString softwareVersion;
